summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/svx/svdotable.hxx2
-rw-r--r--include/svx/svdotext.hxx108
-rw-r--r--sc/source/filter/html/htmlexp2.cxx2
-rw-r--r--svx/source/sdr/properties/customshapeproperties.cxx6
-rw-r--r--svx/source/svdraw/svdoashp.cxx84
-rw-r--r--svx/source/svdraw/svdocirc.cxx85
-rw-r--r--svx/source/svdraw/svdograf.cxx20
-rw-r--r--svx/source/svdraw/svdomeas.cxx18
-rw-r--r--svx/source/svdraw/svdopath.cxx44
-rw-r--r--svx/source/svdraw/svdorect.cxx59
-rw-r--r--svx/source/svdraw/svdotext.cxx222
-rw-r--r--svx/source/svdraw/svdotxat.cxx24
-rw-r--r--svx/source/svdraw/svdotxdr.cxx20
-rw-r--r--svx/source/svdraw/svdotxed.cxx30
-rw-r--r--svx/source/svdraw/svdotxln.cxx56
-rw-r--r--svx/source/svdraw/svdotxtr.cxx78
-rw-r--r--svx/source/svdraw/svdouno.cxx14
-rw-r--r--svx/source/svdraw/textchainflow.cxx4
-rw-r--r--svx/source/table/svdotable.cxx32
-rw-r--r--svx/source/unodraw/unoshap2.cxx2
20 files changed, 456 insertions, 454 deletions
diff --git a/include/svx/svdotable.hxx b/include/svx/svdotable.hxx
index a85bfa6e507a..5d006fe6c3f7 100644
--- a/include/svx/svdotable.hxx
+++ b/include/svx/svdotable.hxx
@@ -177,7 +177,7 @@ public:
// #i121917#
virtual bool HasText() const override;
- bool IsTextEditActive() const { return (pEdtOutl != nullptr); }
+ bool IsTextEditActive() const { return mpEdtOutl != nullptr; }
bool IsTextEditActive( const sdr::table::CellPos& rPos );
/** Returns true only if we are in edit mode and the user actually changed anything */
diff --git a/include/svx/svdotext.hxx b/include/svx/svdotext.hxx
index d5c981d632db..210839c179e4 100644
--- a/include/svx/svdotext.hxx
+++ b/include/svx/svdotext.hxx
@@ -37,7 +37,6 @@
// forward declarations
-
class OutlinerParaObject;
class OverflowingText;
class SdrOutliner;
@@ -82,36 +81,29 @@ namespace sdr::table {
// Defines
-
-
constexpr const sal_uInt16 SDRUSERDATA_OBJTEXTLINK = 1;
// helper class SdrTextObjGeoData
-
-
class SdrTextObjGeoData : public SdrObjGeoData
{
public:
- tools::Rectangle aRect;
- GeoStat aGeo;
+ tools::Rectangle maRect;
+ GeoStat maGeo;
};
// helper class ImpSdrObjTextLinkUserData
-
-
class ImpSdrObjTextLinkUserData final : public SdrObjUserData
{
- friend class SdrTextObj;
- friend class ImpSdrObjTextLink;
+ friend class SdrTextObj;
+ friend class ImpSdrObjTextLink;
- OUString aFileName; // name of the referenced document
- OUString aFilterName; // a filter, if need be
- DateTime aFileDate0; // avoiding unnecessary reload
- tools::SvRef<ImpSdrObjTextLink>
- pLink;
- rtl_TextEncoding eCharSet;
+ OUString maFileName; // name of the referenced document
+ OUString maFilterName; // a filter, if need be
+ DateTime maFileDate0; // avoiding unnecessary reload
+ tools::SvRef<ImpSdrObjTextLink> mpLink;
+ rtl_TextEncoding meCharSet;
public:
ImpSdrObjTextLinkUserData();
@@ -134,12 +126,12 @@ class SVXCORE_DLLPUBLIC SdrTextObj : public SdrAttrObj, public svx::ITextProvide
{
private:
// Cell needs access to ImpGetDrawOutliner();
- friend class sdr::table::Cell;
- friend class sdr::table::SdrTableRtfExporter;
- friend class sdr::table::SdrTableRTFParser;
- friend class TextChain;
- friend class TextChainFlow;
- friend class EditingTextChainFlow;
+ friend class sdr::table::Cell;
+ friend class sdr::table::SdrTableRtfExporter;
+ friend class sdr::table::SdrTableRTFParser;
+ friend class TextChain;
+ friend class TextChainFlow;
+ friend class EditingTextChainFlow;
// CustomShapeproperties need to access the "bTextFrame" member:
friend class sdr::properties::CustomShapeProperties;
@@ -152,7 +144,7 @@ private:
// This method is only allowed for sdr::properties::TextProperties
SVX_DLLPRIVATE SdrOutliner* GetTextEditOutliner() const
{
- return pEdtOutl;
+ return mpEdtOutl;
}
// to allow sdr::properties::TextProperties access to SetPortionInfoChecked()
@@ -160,16 +152,16 @@ private:
friend class sdr::properties::TextProperties;
friend class sdr::properties::CellProperties;
- friend class ImpSdrObjTextLink;
- friend class ImpSdrObjTextLinkUserData;
- friend class SdrPowerPointImport; // for PowerPointImport
- friend class SdrExchangeView; // for ImpGetDrawOutliner
- friend class SdrView; // for ImpGetDrawOutliner
- friend class SdrObjEditView; // for TextEdit
- friend class SdrMeasureObj; // for ImpGetDrawOutliner
- friend class SvxMSDffManager; // for ImpGetDrawOutliner
- friend class SdrObjCustomShape; // for ImpGetDrawOutliner
- friend class SdrText; // for ImpGetDrawOutliner
+ friend class ImpSdrObjTextLink;
+ friend class ImpSdrObjTextLinkUserData;
+ friend class SdrPowerPointImport; // for PowerPointImport
+ friend class SdrExchangeView; // for ImpGetDrawOutliner
+ friend class SdrView; // for ImpGetDrawOutliner
+ friend class SdrObjEditView; // for TextEdit
+ friend class SdrMeasureObj; // for ImpGetDrawOutliner
+ friend class SvxMSDffManager; // for ImpGetDrawOutliner
+ friend class SdrObjCustomShape; // for ImpGetDrawOutliner
+ friend class SdrText; // for ImpGetDrawOutliner
protected:
// The "aRect" is also the rect of RectObj and CircObj.
@@ -178,18 +170,18 @@ protected:
tools::Rectangle maRect;
// The GeoStat contains the rotation and shear angles
- GeoStat aGeo;
+ GeoStat maGeo;
// this is the active text
- std::unique_ptr<SdrText> mpText;
+ std::unique_ptr<SdrText> mpText;
// This contains the dimensions of the text
- Size aTextSize;
+ Size maTextSize;
// an Outliner*, so that
// 1. the TextObj won't be edited simultaneously by multiple views, and
// 2. when streaming while editing Flush() can be done
- SdrOutliner* pEdtOutl;
+ SdrOutliner* mpEdtOutl;
// Possible values for eTextKind are:
// OBJ_TEXT regular text frame
@@ -197,13 +189,13 @@ protected:
// OBJ_OUTLINETEXT OutlineText for presentations
// eTextKind only has meaning when bTextFrame=sal_True, since otherwise
// we're dealing with a labeled graphical object
- SdrObjKind eTextKind;
+ SdrObjKind meTextKind;
// For text editing in SW Header/Footer it is necessary to be
// able to set an offset for the text edit to allow text editing at the
// position of the virtual object. This offset is used when setting up
// and maintaining the OutlinerView.
- Point maTextEditOffset;
+ Point maTextEditOffset;
virtual SdrObjectUniquePtr getFullDragClone() const override;
@@ -216,19 +208,19 @@ protected:
bool mbIsUnchainableClone = false;
// the successor in a chain
- SdrTextObj *mpNextInChain = nullptr;
- SdrTextObj *mpPrevInChain = nullptr;
+ SdrTextObj* mpNextInChain = nullptr;
+ SdrTextObj* mpPrevInChain = nullptr;
// For labeled graphical objects bTextFrame is FALSE. The block of text
// will then be centered horizontally and vertically on aRect.
// For bTextFalse=sal_True the text will be formatted into aRect.
// The actual text frame is realized by an SdrRectObj with
// bTextFrame=sal_True.
- bool bTextFrame : 1;
- bool bNoShear : 1; // disable shearing (->graphic+Ole+TextFrame)
- bool bTextSizeDirty : 1;
+ bool mbTextFrame : 1;
+ bool mbNoShear : 1; // disable shearing (->graphic+Ole+TextFrame)
+ bool mbTextSizeDirty : 1;
- bool mbInEditMode : 1; // Is this text object in edit mode?
+ bool mbInEditMode : 1; // Is this text object in edit mode?
// For objects with free size (flow text). The flag is set by the
// application on create. If the object width is later resized,
@@ -238,13 +230,13 @@ protected:
// Width resize can result from:
// - Interactive Resize in single or multiple selections
// - position/size dialog
- bool bDisableAutoWidthOnDragging : 1;
+ bool mbDisableAutoWidthOnDragging : 1;
// Flag for allowing text animation. Default is sal_true.
- bool mbTextAnimationAllowed : 1;
+ bool mbTextAnimationAllowed : 1;
// flag for preventing recursive onEditOutlinerStatusEvent calls
- bool mbInDownScale : 1;
+ bool mbInDownScale : 1;
SdrOutliner& ImpGetDrawOutliner() const;
@@ -281,7 +273,7 @@ protected:
void ImpCheckShear();
tools::Rectangle ImpDragCalcRect(const SdrDragStat& rDrag) const;
void ImpSetTextEditParams() const;
- void SetTextSizeDirty() { bTextSizeDirty=true; }
+ void SetTextSizeDirty() { mbTextSizeDirty = true; }
// rAnchorRect is InOut-Parameter!
void ImpSetContourPolygon( SdrOutliner& rOutliner, tools::Rectangle const & rAnchorRect, bool bLineWidth ) const;
@@ -332,15 +324,15 @@ public:
// Setting attributes can only be done on the text frame.
void SetTextLink(const OUString& rFileName, const OUString& rFilterName);
void ReleaseTextLink();
- bool IsLinkedText() const { return m_pPlusData!=nullptr && GetLinkUserData()!=nullptr; }
+ bool IsLinkedText() const { return m_pPlusData != nullptr && GetLinkUserData() != nullptr; }
bool ReloadLinkedText(bool bForceLoad);
bool LoadText(const OUString& rFileName, rtl_TextEncoding eCharSet);
virtual bool AdjustTextFrameWidthAndHeight(tools::Rectangle& rR, bool bHgt = true, bool bWdt = true) const;
virtual bool NbcAdjustTextFrameWidthAndHeight(bool bHgt = true, bool bWdt = true);
virtual bool AdjustTextFrameWidthAndHeight();
- bool IsTextFrame() const { return bTextFrame; }
- bool IsOutlText() const { return bTextFrame && (eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT); }
+ bool IsTextFrame() const { return mbTextFrame; }
+ bool IsOutlText() const { return mbTextFrame && (meTextKind==OBJ_OUTLINETEXT || meTextKind==OBJ_TITLETEXT); }
/// returns true if the PPT autofit of text into shape bounds is enabled. implies IsFitToSize()==false!
bool IsAutoFit() const;
/// returns true if the old feature for fitting shape content should into shape is enabled. implies IsAutoFit()==false!
@@ -354,12 +346,12 @@ public:
bool GetPreventChainable() const;
TextChain *GetTextChain() const;
- SdrObjKind GetTextKind() const { return eTextKind; }
+ SdrObjKind GetTextKind() const { return meTextKind; }
// #i121917#
virtual bool HasText() const override;
- bool IsTextEditActive() const { return pEdtOutl != nullptr; }
+ bool IsTextEditActive() const { return mpEdtOutl != nullptr; }
/** returns the currently active text. */
virtual SdrText* getActiveText() const;
@@ -379,7 +371,7 @@ public:
/** returns the index of the text that contains the given point or -1 */
virtual sal_Int32 CheckTextHit(const Point& rPnt) const;
- void SetDisableAutoWidthOnDragging(bool bOn) { bDisableAutoWidthOnDragging=bOn; }
+ void SetDisableAutoWidthOnDragging(bool bOn) { mbDisableAutoWidthOnDragging=bOn; }
void NbcSetText(const OUString& rStr);
void SetText(const OUString& rStr);
void NbcSetText(SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat);
@@ -395,7 +387,7 @@ public:
virtual void TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle& rTextRect, bool bNoEditText,
tools::Rectangle* pAnchorRect, bool bLineWidth = true ) const;
virtual void TakeTextAnchorRect(::tools::Rectangle& rAnchorRect) const;
- const GeoStat& GetGeoStat() const { return aGeo; }
+ const GeoStat& GetGeoStat() const { return maGeo; }
// get corner radius
tools::Long GetEckenradius() const;
@@ -507,7 +499,7 @@ public:
virtual SdrObjectUniquePtr DoConvertToPolyObj(bool bBezier, bool bAddText) const override;
- void SetTextEditOutliner(SdrOutliner* pOutl) { pEdtOutl=pOutl; }
+ void SetTextEditOutliner(SdrOutliner* pOutl) { mpEdtOutl = pOutl; }
/** Setup given Outliner equivalently to SdrTextObj::Paint()
diff --git a/sc/source/filter/html/htmlexp2.cxx b/sc/source/filter/html/htmlexp2.cxx
index a113318d408d..055a04f81f81 100644
--- a/sc/source/filter/html/htmlexp2.cxx
+++ b/sc/source/filter/html/htmlexp2.cxx
@@ -133,7 +133,7 @@ void ScHTMLExport::WriteGraphEntry( ScHTMLGraphEntry* pE )
{
const SdrGrafObj* pSGO = static_cast<SdrGrafObj*>(pObject);
std::unique_ptr<SdrGrafObjGeoData> pGeo(static_cast<SdrGrafObjGeoData*>(pSGO->GetGeoData().release()));
- sal_uInt16 nMirrorCase = (pGeo->aGeo.nRotationAngle == 18000_deg100 ?
+ sal_uInt16 nMirrorCase = (pGeo->maGeo.nRotationAngle == 18000_deg100 ?
( pGeo->bMirrored ? 3 : 4 ) : ( pGeo->bMirrored ? 2 : 1 ));
bool bHMirr = ( ( nMirrorCase == 2 ) || ( nMirrorCase == 4 ) );
bool bVMirr = ( ( nMirrorCase == 3 ) || ( nMirrorCase == 4 ) );
diff --git a/svx/source/sdr/properties/customshapeproperties.cxx b/svx/source/sdr/properties/customshapeproperties.cxx
index 07c893d1cf51..a621e3d84e71 100644
--- a/svx/source/sdr/properties/customshapeproperties.cxx
+++ b/svx/source/sdr/properties/customshapeproperties.cxx
@@ -34,14 +34,14 @@ namespace sdr::properties
void CustomShapeProperties::UpdateTextFrameStatus(bool bInvalidateRenderGeometry)
{
SdrObjCustomShape& rObj = static_cast< SdrObjCustomShape& >(GetSdrObject());
- const bool bOld(rObj.bTextFrame);
+ const bool bOld(rObj.mbTextFrame);
// change TextFrame flag when bResizeShapeToFitText changes (which is mapped
// on the item SDRATTR_TEXT_AUTOGROWHEIGHT for custom shapes, argh)
- rObj.bTextFrame = GetObjectItemSet().Get(SDRATTR_TEXT_AUTOGROWHEIGHT).GetValue();
+ rObj.mbTextFrame = GetObjectItemSet().Get(SDRATTR_TEXT_AUTOGROWHEIGHT).GetValue();
// check if it did change
- if(rObj.bTextFrame != bOld)
+ if(rObj.mbTextFrame != bOld)
{
// on change also invalidate render geometry
bInvalidateRenderGeometry = true;
diff --git a/svx/source/svdraw/svdocirc.cxx b/svx/source/svdraw/svdocirc.cxx
index 4250b762ea86..6739e6082a57 100644
--- a/svx/source/svdraw/svdocirc.cxx
+++ b/svx/source/svdraw/svdocirc.cxx
@@ -194,7 +194,7 @@ bool SdrCircObj::PaintNeedsXPolyCirc() const
// ellipse segments.
// If not WIN, then (for now) also for circle/ellipse segments and circle/
// ellipse arcs (for precision)
- bool bNeed=aGeo.nRotationAngle || aGeo.nShearAngle || meCircleKind==SdrCircKind::Cut;
+ bool bNeed = maGeo.nRotationAngle || maGeo.nShearAngle || meCircleKind == SdrCircKind::Cut;
// If not WIN, then for everything except full circle (for now!)
if (meCircleKind!=SdrCircKind::Full) bNeed = true;
@@ -291,7 +291,7 @@ basegfx::B2DPolygon SdrCircObj::ImpCalcXPolyCirc(const SdrCircKind eCircleKind,
}
// #i76950#
- if(aGeo.nShearAngle || aGeo.nRotationAngle)
+ if (maGeo.nShearAngle || maGeo.nRotationAngle)
{
// translate top left to (0,0)
const basegfx::B2DPoint aTopLeft(aRange.getMinimum());
@@ -300,8 +300,8 @@ basegfx::B2DPolygon SdrCircObj::ImpCalcXPolyCirc(const SdrCircKind eCircleKind,
// shear, rotate and back to top left (if needed)
aMatrix = basegfx::utils::createShearXRotateTranslateB2DHomMatrix(
- -aGeo.mfTanShearAngle,
- aGeo.nRotationAngle ? (36000_deg100 - aGeo.nRotationAngle).get() * F_PI18000 : 0.0,
+ -maGeo.mfTanShearAngle,
+ maGeo.nRotationAngle ? (36000_deg100 - maGeo.nRotationAngle).get() * F_PI18000 : 0.0,
aTopLeft) * aMatrix;
// apply transformation
@@ -320,7 +320,7 @@ void SdrCircObj::RecalcXPoly()
OUString SdrCircObj::TakeObjNameSingul() const
{
const char* pID=STR_ObjNameSingulCIRC;
- if (maRect.GetWidth() == maRect.GetHeight() && aGeo.nShearAngle==0_deg100)
+ if (maRect.GetWidth() == maRect.GetHeight() && maGeo.nShearAngle==0_deg100)
{
switch (meCircleKind) {
case SdrCircKind::Full: pID=STR_ObjNameSingulCIRC; break;
@@ -349,7 +349,7 @@ OUString SdrCircObj::TakeObjNameSingul() const
OUString SdrCircObj::TakeObjNamePlural() const
{
const char* pID=STR_ObjNamePluralCIRC;
- if (maRect.GetWidth() == maRect.GetHeight() && aGeo.nShearAngle==0_deg100)
+ if (maRect.GetWidth() == maRect.GetHeight() && maGeo.nShearAngle==0_deg100)
{
switch (meCircleKind) {
case SdrCircKind::Full: pID=STR_ObjNamePluralCIRC; break;
@@ -471,20 +471,20 @@ void SdrCircObj::AddToHdlList(SdrHdlList& rHdlList) const
break;
}
- if (aGeo.nShearAngle)
+ if (maGeo.nShearAngle)
{
- ShearPoint(aPnt,maRect.TopLeft(),aGeo.mfTanShearAngle);
+ ShearPoint(aPnt, maRect.TopLeft(), maGeo.mfTanShearAngle);
}
- if (aGeo.nRotationAngle)
+ if (maGeo.nRotationAngle)
{
- RotatePoint(aPnt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aPnt, maRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
}
std::unique_ptr<SdrHdl> pH(new SdrHdl(aPnt,eLocalKind));
pH->SetPointNum(nPNum);
pH->SetObj(const_cast<SdrCircObj*>(this));
- pH->SetRotationAngle(aGeo.nRotationAngle);
+ pH->SetRotationAngle(maGeo.nRotationAngle);
rHdlList.AddHdl(std::move(pH));
}
}
@@ -520,11 +520,11 @@ bool SdrCircObj::applySpecialDrag(SdrDragStat& rDrag)
{
Point aPt(rDrag.GetNow());
- if (aGeo.nRotationAngle)
- RotatePoint(aPt,maRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ RotatePoint(aPt,maRect.TopLeft(), -maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
- if (aGeo.nShearAngle)
- ShearPoint(aPt,maRect.TopLeft(),-aGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle)
+ ShearPoint(aPt,maRect.TopLeft(), -maGeo.mfTanShearAngle);
aPt -= maRect.Center();
@@ -819,10 +819,10 @@ void SdrCircObj::NbcMove(const Size& aSiz)
void SdrCircObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact)
{
- Degree100 nAngle0=aGeo.nRotationAngle;
- bool bNoShearRota=(aGeo.nRotationAngle==0_deg100 && aGeo.nShearAngle==0_deg100);
+ Degree100 nAngle0 = maGeo.nRotationAngle;
+ bool bNoShearRota = (maGeo.nRotationAngle == 0_deg100 && maGeo.nShearAngle == 0_deg100);
SdrTextObj::NbcResize(rRef,xFact,yFact);
- bNoShearRota|=(aGeo.nRotationAngle==0_deg100 && aGeo.nShearAngle==0_deg100);
+ bNoShearRota |= (maGeo.nRotationAngle == 0_deg100 && maGeo.nShearAngle == 0_deg100);
if (meCircleKind!=SdrCircKind::Full) {
bool bXMirr=(xFact.GetNumerator()<0) != (xFact.GetDenominator()<0);
bool bYMirr=(yFact.GetNumerator()<0) != (yFact.GetDenominator()<0);
@@ -854,8 +854,8 @@ void SdrCircObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
nS0=-nE0;
nE0=-nTmp;
}
- nS0-=aGeo.nRotationAngle;
- nE0-=aGeo.nRotationAngle;
+ nS0 -= maGeo.nRotationAngle;
+ nE0 -= maGeo.nRotationAngle;
}
}
Degree100 nAngleDif=nE0-nS0;
@@ -898,13 +898,15 @@ void SdrCircObj::NbcMirror(const Point& rRef1, const Point& rRef2)
if (nWdt==0) aTmpPt2.setX(0 );
if (nHgt==0) aTmpPt2.setY(0 );
aTmpPt2+=aCenter;
- if (aGeo.nRotationAngle) {
- RotatePoint(aTmpPt1,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
- RotatePoint(aTmpPt2,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ {
+ RotatePoint(aTmpPt1, maRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
+ RotatePoint(aTmpPt2, maRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
}
- if (aGeo.nShearAngle) {
- ShearPoint(aTmpPt1,maRect.TopLeft(),aGeo.mfTanShearAngle);
- ShearPoint(aTmpPt2,maRect.TopLeft(),aGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle)
+ {
+ ShearPoint(aTmpPt1, maRect.TopLeft(), maGeo.mfTanShearAngle);
+ ShearPoint(aTmpPt2, maRect.TopLeft(), maGeo.mfTanShearAngle);
}
}
SdrTextObj::NbcMirror(rRef1,rRef2);
@@ -912,14 +914,16 @@ void SdrCircObj::NbcMirror(const Point& rRef1, const Point& rRef2)
MirrorPoint(aTmpPt1,rRef1,rRef2);
MirrorPoint(aTmpPt2,rRef1,rRef2);
// unrotate:
- if (aGeo.nRotationAngle) {
- RotatePoint(aTmpPt1,maRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle); // -sin for reversion
- RotatePoint(aTmpPt2,maRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle); // -sin for reversion
+ if (maGeo.nRotationAngle)
+ {
+ RotatePoint(aTmpPt1, maRect.TopLeft(), -maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle); // -sin for reversion
+ RotatePoint(aTmpPt2, maRect.TopLeft(), -maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle); // -sin for reversion
}
// unshear:
- if (aGeo.nShearAngle) {
- ShearPoint(aTmpPt1,maRect.TopLeft(),-aGeo.mfTanShearAngle); // -tan for reversion
- ShearPoint(aTmpPt2,maRect.TopLeft(),-aGeo.mfTanShearAngle); // -tan for reversion
+ if (maGeo.nShearAngle)
+ {
+ ShearPoint(aTmpPt1, maRect.TopLeft(), -maGeo.mfTanShearAngle); // -tan for reversion
+ ShearPoint(aTmpPt2, maRect.TopLeft(), -maGeo.mfTanShearAngle); // -tan for reversion
}
Point aCenter(maRect.Center());
aTmpPt1-=aCenter;
@@ -996,24 +1000,26 @@ void SdrCircObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
if (meCircleKind==SdrCircKind::Section) {
Union(rRect,maRect.Center());
}
- if (aGeo.nRotationAngle) {
+ if (maGeo.nRotationAngle)
+ {
Point aDst(rRect.TopLeft());
aDst-=maRect.TopLeft();
Point aDst0(aDst);
- RotatePoint(aDst,Point(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aDst,Point(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aDst-=aDst0;
rRect.Move(aDst.X(),aDst.Y());
}
}
- if (aGeo.nShearAngle==0_deg100)
+ if (maGeo.nShearAngle==0_deg100)
return;
- tools::Long nDst=FRound((rRect.Bottom()-rRect.Top())*aGeo.mfTanShearAngle);
- if (aGeo.nShearAngle>0_deg100) {
+ tools::Long nDst = FRound((rRect.Bottom() - rRect.Top()) * maGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle > 0_deg100)
+ {
Point aRef(rRect.TopLeft());
rRect.AdjustLeft( -nDst );
Point aTmpPt(rRect.TopLeft());
- RotatePoint(aTmpPt,aRef,aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aTmpPt, aRef, maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aTmpPt-=rRect.TopLeft();
rRect.Move(aTmpPt.X(),aTmpPt.Y());
} else {
@@ -1032,7 +1038,8 @@ void SdrCircObj::RecalcSnapRect()
void SdrCircObj::NbcSetSnapRect(const tools::Rectangle& rRect)
{
- if (aGeo.nRotationAngle || aGeo.nShearAngle || meCircleKind!=SdrCircKind::Full) {
+ if (maGeo.nRotationAngle || maGeo.nShearAngle || meCircleKind != SdrCircKind::Full)
+ {
tools::Rectangle aSR0(GetSnapRect());
tools::Long nWdt0=aSR0.Right()-aSR0.Left();
tools::Long nHgt0=aSR0.Bottom()-aSR0.Top();
diff --git a/svx/source/svdraw/svdograf.cxx b/svx/source/svdraw/svdograf.cxx
index 1c8871127fe3..5ec2219cbef3 100644
--- a/svx/source/svdraw/svdograf.cxx
+++ b/svx/source/svdraw/svdograf.cxx
@@ -193,7 +193,7 @@ SdrGrafObj::SdrGrafObj(SdrModel& rSdrModel)
onGraphicChanged();
// #i118485# Shear allowed and possible now
- bNoShear = false;
+ mbNoShear = false;
mbGrafAnimationAllowed = true;
@@ -212,7 +212,7 @@ SdrGrafObj::SdrGrafObj(SdrModel& rSdrModel, SdrGrafObj const & rSource)
onGraphicChanged();
// #i118485# Shear allowed and possible now
- bNoShear = false;
+ mbNoShear = false;
mbGrafAnimationAllowed = true;
@@ -274,7 +274,7 @@ SdrGrafObj::SdrGrafObj(
onGraphicChanged();
// #i118485# Shear allowed and possible now
- bNoShear = false;
+ mbNoShear = false;
mbGrafAnimationAllowed = true;
@@ -300,7 +300,7 @@ SdrGrafObj::SdrGrafObj(
onGraphicChanged();
// #i118485# Shear allowed and possible now
- bNoShear = false;
+ mbNoShear = false;
mbGrafAnimationAllowed = true;
@@ -416,7 +416,7 @@ GraphicAttr SdrGrafObj::GetGraphicAttr( SdrGrafObjTransformsAttrs nTransformFlag
{
const bool bMirror = bool( nTransformFlags & SdrGrafObjTransformsAttrs::MIRROR );
const bool bRotate = bool( nTransformFlags & SdrGrafObjTransformsAttrs::ROTATE ) &&
- (aGeo.nRotationAngle && aGeo.nRotationAngle != 18000_deg100);
+ (maGeo.nRotationAngle && maGeo.nRotationAngle != 18000_deg100);
// Need cropping info earlier
const_cast<SdrGrafObj*>(this)->ImpSetAttrToGrafInfo();
@@ -427,7 +427,7 @@ GraphicAttr SdrGrafObj::GetGraphicAttr( SdrGrafObjTransformsAttrs nTransformFlag
if( bMirror )
{
- sal_uInt16 nMirrorCase = ( aGeo.nRotationAngle == 18000_deg100 ) ? ( bMirrored ? 3 : 4 ) : ( bMirrored ? 2 : 1 );
+ sal_uInt16 nMirrorCase = ( maGeo.nRotationAngle == 18000_deg100 ) ? ( bMirrored ? 3 : 4 ) : ( bMirrored ? 2 : 1 );
bool bHMirr = nMirrorCase == 2 || nMirrorCase == 4;
bool bVMirr = nMirrorCase == 3 || nMirrorCase == 4;
@@ -435,7 +435,7 @@ GraphicAttr SdrGrafObj::GetGraphicAttr( SdrGrafObjTransformsAttrs nTransformFlag
}
if( bRotate )
- aActAttr.SetRotation( toDegree10(aGeo.nRotationAngle ) );
+ aActAttr.SetRotation( toDegree10(maGeo.nRotationAngle ) );
}
return aActAttr;
@@ -567,9 +567,9 @@ void SdrGrafObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
{
bool bNoPresGrf = ( mpGraphicObject->GetType() != GraphicType::NONE ) && !m_bEmptyPresObj;
- rInfo.bResizeFreeAllowed = aGeo.nRotationAngle.get() % 9000 == 0 ||
- aGeo.nRotationAngle.get() % 18000 == 0 ||
- aGeo.nRotationAngle.get() % 27000 == 0;
+ rInfo.bResizeFreeAllowed = maGeo.nRotationAngle.get() % 9000 == 0 ||
+ maGeo.nRotationAngle.get() % 18000 == 0 ||
+ maGeo.nRotationAngle.get() % 27000 == 0;
rInfo.bResizePropAllowed = true;
rInfo.bRotateFreeAllowed = bNoPresGrf;
diff --git a/svx/source/svdraw/svdomeas.cxx b/svx/source/svdraw/svdomeas.cxx
index db470844e4e0..1d8b59698ebb 100644
--- a/svx/source/svdraw/svdomeas.cxx
+++ b/svx/source/svdraw/svdomeas.cxx
@@ -607,9 +607,9 @@ void SdrMeasureObj::UndirtyText() const
Size aSiz(rOutliner.CalcTextSize());
rOutliner.Clear();
// cast to nonconst three times
- const_cast<SdrMeasureObj*>(this)->aTextSize=aSiz;
- const_cast<SdrMeasureObj*>(this)->bTextSizeDirty=false;
- const_cast<SdrMeasureObj*>(this)->bTextDirty=false;
+ const_cast<SdrMeasureObj*>(this)->maTextSize = aSiz;
+ const_cast<SdrMeasureObj*>(this)->mbTextSizeDirty = false;
+ const_cast<SdrMeasureObj*>(this)->bTextDirty = false;
}
void SdrMeasureObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
@@ -691,9 +691,9 @@ void SdrMeasureObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
aTextPos.AdjustY( -(aTextSize2.Width()) );
}
}
- if (aMPol.nTextAngle!=aGeo.nRotationAngle) {
- const_cast<SdrMeasureObj*>(this)->aGeo.nRotationAngle=aMPol.nTextAngle;
- const_cast<SdrMeasureObj*>(this)->aGeo.RecalcSinCos();
+ if (aMPol.nTextAngle != maGeo.nRotationAngle) {
+ const_cast<SdrMeasureObj*>(this)->maGeo.nRotationAngle=aMPol.nTextAngle;
+ const_cast<SdrMeasureObj*>(this)->maGeo.RecalcSinCos();
}
RotatePoint(aTextPos,aPt1b,aMPol.nLineSin,aMPol.nLineCos);
aTextSize2.AdjustWidth( 1 ); aTextSize2.AdjustHeight( 1 ); // because of the Rect-Ctor's odd behavior
@@ -701,9 +701,9 @@ void SdrMeasureObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
rRect.Justify();
const_cast<SdrMeasureObj*>(this)->maRect=rRect;
- if (aMPol.nTextAngle!=aGeo.nRotationAngle) {
- const_cast<SdrMeasureObj*>(this)->aGeo.nRotationAngle=aMPol.nTextAngle;
- const_cast<SdrMeasureObj*>(this)->aGeo.RecalcSinCos();
+ if (aMPol.nTextAngle != maGeo.nRotationAngle) {
+ const_cast<SdrMeasureObj*>(this)->maGeo.nRotationAngle=aMPol.nTextAngle;
+ const_cast<SdrMeasureObj*>(this)->maGeo.RecalcSinCos();
}
}
diff --git a/svx/source/svdraw/svdorect.cxx b/svx/source/svdraw/svdorect.cxx
index 825bf866ee96..7221a3c71b76 100644
--- a/svx/source/svdraw/svdorect.cxx
+++ b/svx/source/svdraw/svdorect.cxx
@@ -80,8 +80,8 @@ SdrRectObj::SdrRectObj(
SdrObjKind eNewTextKind)
: SdrTextObj(rSdrModel, eNewTextKind)
{
- DBG_ASSERT(eTextKind==OBJ_TEXT ||
- eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT,
+ DBG_ASSERT(meTextKind == OBJ_TEXT ||
+ meTextKind == OBJ_OUTLINETEXT || meTextKind == OBJ_TITLETEXT,
"SdrRectObj::SdrRectObj(SdrObjKind) can only be applied to text frames.");
m_bClosedObj=true;
}
@@ -92,8 +92,8 @@ SdrRectObj::SdrRectObj(
const tools::Rectangle& rRect)
: SdrTextObj(rSdrModel, eNewTextKind, rRect)
{
- DBG_ASSERT(eTextKind==OBJ_TEXT ||
- eTextKind==OBJ_OUTLINETEXT || eTextKind==OBJ_TITLETEXT,
+ DBG_ASSERT(meTextKind == OBJ_TEXT ||
+ meTextKind == OBJ_OUTLINETEXT || meTextKind == OBJ_TITLETEXT,
"SdrRectObj::SdrRectObj(SdrObjKind,...) can only be applied to text frames.");
m_bClosedObj=true;
}
@@ -126,8 +126,8 @@ XPolygon SdrRectObj::ImpCalcXPoly(const tools::Rectangle& rRect1, tools::Long nR
aXPoly=aNewPoly;
// these angles always relate to the top left corner of aRect
- if (aGeo.nShearAngle) ShearXPoly(aXPoly,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotateXPoly(aXPoly,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearXPoly(aXPoly,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotateXPoly(aXPoly,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
return aXPoly;
}
@@ -149,7 +149,7 @@ const XPolygon& SdrRectObj::GetXPoly() const
void SdrRectObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
{
bool bNoTextFrame=!IsTextFrame();
- rInfo.bResizeFreeAllowed=bNoTextFrame || ((aGeo.nRotationAngle.get() % 9000) == 0);
+ rInfo.bResizeFreeAllowed=bNoTextFrame || ((maGeo.nRotationAngle.get() % 9000) == 0);
rInfo.bResizePropAllowed=true;
rInfo.bRotateFreeAllowed=true;
rInfo.bRotate90Allowed =true;
@@ -174,23 +174,24 @@ void SdrRectObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
SdrObjKind SdrRectObj::GetObjIdentifier() const
{
- if (IsTextFrame()) return eTextKind;
+ if (IsTextFrame())
+ return meTextKind;
else return OBJ_RECT;
}
void SdrRectObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
{
rRect = maRect;
- if (aGeo.nShearAngle==0_deg100)
+ if (maGeo.nShearAngle==0_deg100)
return;
- tools::Long nDst=FRound((maRect.Bottom()-maRect.Top())*aGeo.mfTanShearAngle);
- if (aGeo.nShearAngle>0_deg100)
+ tools::Long nDst=FRound((maRect.Bottom()-maRect.Top()) * maGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle>0_deg100)
{
Point aRef(rRect.TopLeft());
rRect.AdjustLeft( -nDst );
Point aTmpPt(rRect.TopLeft());
- RotatePoint(aTmpPt,aRef,aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aTmpPt,aRef,maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aTmpPt-=rRect.TopLeft();
rRect.Move(aTmpPt.X(),aTmpPt.Y());
}
@@ -209,7 +210,7 @@ OUString SdrRectObj::TakeObjNameSingul() const
bool bRounded = GetEckenradius() != 0; // rounded down
const char* pResId = bRounded ? STR_ObjNameSingulRECTRND : STR_ObjNameSingulRECT;
- if (aGeo.nShearAngle)
+ if (maGeo.nShearAngle)
{
pResId = bRounded ? STR_ObjNameSingulPARALRND : STR_ObjNameSingulPARAL; // parallelogram or, maybe, rhombus
}
@@ -235,7 +236,7 @@ OUString SdrRectObj::TakeObjNamePlural() const
bool bRounded = GetEckenradius() != 0; // rounded down
const char* pResId = bRounded ? STR_ObjNamePluralRECTRND : STR_ObjNamePluralRECT;
- if (aGeo.nShearAngle)
+ if (maGeo.nShearAngle)
{
pResId = bRounded ? STR_ObjNamePluralPARALRND : STR_ObjNamePluralPARAL; // parallelogram or rhombus
}
@@ -262,7 +263,7 @@ basegfx::B2DPolyPolygon SdrRectObj::TakeXorPoly() const
void SdrRectObj::RecalcSnapRect()
{
tools::Long nEckRad=GetEckenradius();
- if ((aGeo.nRotationAngle || aGeo.nShearAngle) && nEckRad!=0) {
+ if ((maGeo.nRotationAngle || maGeo.nShearAngle) && nEckRad!=0) {
maSnapRect=GetXPoly().GetBoundRect();
} else {
SdrTextObj::RecalcSnapRect();
@@ -294,7 +295,7 @@ void SdrRectObj::AddToHdlList(SdrHdlList& rHdlList) const
OSL_ENSURE(!IsTextEditActive(), "Do not use an ImpTextframeHdl for highlighting text in active text edit, this will collide with EditEngine paints (!)");
std::unique_ptr<SdrHdl> pH(new ImpTextframeHdl(maRect));
pH->SetObj(const_cast<SdrRectObj*>(this));
- pH->SetRotationAngle(aGeo.nRotationAngle);
+ pH->SetRotationAngle(maGeo.nRotationAngle);
rHdlList.AddHdl(std::move(pH));
}
@@ -326,18 +327,18 @@ void SdrRectObj::AddToHdlList(SdrHdlList& rHdlList) const
case 9: aPnt=maRect.BottomRight(); eKind = SdrHdlKind::LowerRight; break;
}
- if(aGeo.nShearAngle)
+ if (maGeo.nShearAngle)
{
- ShearPoint(aPnt,maRect.TopLeft(),aGeo.mfTanShearAngle);
+ ShearPoint(aPnt,maRect.TopLeft(),maGeo.mfTanShearAngle);
}
- if(aGeo.nRotationAngle)
+ if (maGeo.nRotationAngle)
{
- RotatePoint(aPnt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aPnt,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
}
std::unique_ptr<SdrHdl> pH(new SdrHdl(aPnt,eKind));
pH->SetObj(const_cast<SdrRectObj*>(this));
- pH->SetRotationAngle(aGeo.nRotationAngle);
+ pH->SetRotationAngle(maGeo.nRotationAngle);
rHdlList.AddHdl(std::move(pH));
}
}
@@ -369,8 +370,8 @@ bool SdrRectObj::applySpecialDrag(SdrDragStat& rDrag)
{
Point aPt(rDrag.GetNow());
- if(aGeo.nRotationAngle)
- RotatePoint(aPt,maRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ RotatePoint(aPt, maRect.TopLeft(), -maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
sal_Int32 nRad(aPt.X() - maRect.Left());
@@ -407,8 +408,8 @@ OUString SdrRectObj::getSpecialDragComment(const SdrDragStat& rDrag) const
Point aPt(rDrag.GetNow());
// -sin for reversal
- if(aGeo.nRotationAngle)
- RotatePoint(aPt, maRect.TopLeft(), -aGeo.mfSinRotationAngle, aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ RotatePoint(aPt, maRect.TopLeft(), -maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
sal_Int32 nRad(aPt.X() - maRect.Left());
@@ -493,8 +494,8 @@ SdrGluePoint SdrRectObj::GetVertexGluePoint(sal_uInt16 nPosNum) const
case 2: aPt=maRect.BottomCenter(); aPt.AdjustY(nWdt ); break;
case 3: aPt=maRect.LeftCenter(); aPt.AdjustX( -nWdt ); break;
}
- if (aGeo.nShearAngle) ShearPoint(aPt,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoint(aPt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoint(aPt, maRect.TopLeft(), maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoint(aPt, maRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aPt-=GetSnapRect().Center();
SdrGluePoint aGP(aPt);
aGP.SetPercent(false);
@@ -519,8 +520,8 @@ SdrGluePoint SdrRectObj::GetCornerGluePoint(sal_uInt16 nPosNum) const
case 2: aPt=maRect.BottomRight(); aPt.AdjustX(nWdt ); aPt.AdjustY(nWdt ); break;
case 3: aPt=maRect.BottomLeft(); aPt.AdjustX( -nWdt ); aPt.AdjustY(nWdt ); break;
}
- if (aGeo.nShearAngle) ShearPoint(aPt,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoint(aPt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoint(aPt,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoint(aPt,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aPt-=GetSnapRect().Center();
SdrGluePoint aGP(aPt);
aGP.SetPercent(false);
diff --git a/svx/source/svdraw/svdotext.cxx b/svx/source/svdraw/svdotext.cxx
index 52708ba56971..d3377570398e 100644
--- a/svx/source/svdraw/svdotext.cxx
+++ b/svx/source/svdraw/svdotext.cxx
@@ -69,13 +69,13 @@ std::unique_ptr<sdr::contact::ViewContact> SdrTextObj::CreateObjectSpecificViewC
SdrTextObj::SdrTextObj(SdrModel& rSdrModel)
: SdrAttrObj(rSdrModel),
- pEdtOutl(nullptr),
- eTextKind(OBJ_TEXT)
+ mpEdtOutl(nullptr),
+ meTextKind(OBJ_TEXT)
{
- bTextSizeDirty=false;
- bTextFrame=false;
- bNoShear=false;
- bDisableAutoWidthOnDragging=false;
+ mbTextSizeDirty = false;
+ mbTextFrame = false;
+ mbNoShear = false;
+ mbDisableAutoWidthOnDragging = false;
mbInEditMode = false;
mbTextAnimationAllowed = true;
@@ -88,7 +88,7 @@ SdrTextObj::SdrTextObj(SdrModel& rSdrModel)
SdrTextObj::SdrTextObj(SdrModel& rSdrModel, SdrTextObj const & rSource)
: SdrAttrObj(rSdrModel, rSource),
- pEdtOutl(nullptr)
+ mpEdtOutl(nullptr)
{
mbInEditMode = false;
mbTextAnimationAllowed = true;
@@ -99,15 +99,15 @@ SdrTextObj::SdrTextObj(SdrModel& rSdrModel, SdrTextObj const & rSource)
mbInDownScale = false;
maRect = rSource.maRect;
- aGeo =rSource.aGeo;
- eTextKind =rSource.eTextKind;
- bTextFrame=rSource.bTextFrame;
- aTextSize=rSource.aTextSize;
- bTextSizeDirty=rSource.bTextSizeDirty;
+ maGeo = rSource.maGeo;
+ meTextKind = rSource.meTextKind;
+ mbTextFrame = rSource.mbTextFrame;
+ maTextSize = rSource.maTextSize;
+ mbTextSizeDirty = rSource.mbTextSizeDirty;
// Not all of the necessary parameters were copied yet.
- bNoShear = rSource.bNoShear;
- bDisableAutoWidthOnDragging = rSource.bDisableAutoWidthOnDragging;
+ mbNoShear = rSource.mbNoShear;
+ mbDisableAutoWidthOnDragging = rSource.mbDisableAutoWidthOnDragging;
SdrText* pText = getActiveText();
if( pText && rSource.HasText() )
@@ -117,7 +117,7 @@ SdrTextObj::SdrTextObj(SdrModel& rSdrModel, SdrTextObj const & rSource)
// empty (this operator== seems not prepared for MultiText
// objects). In the current form it makes only sense to
// create locally and use locally on a known existing SdrText
- const Outliner* pEO=rSource.pEdtOutl;
+ const Outliner* pEO = rSource.mpEdtOutl;
std::unique_ptr<OutlinerParaObject> pNewOutlinerParaObject;
if (pEO!=nullptr)
@@ -140,13 +140,13 @@ SdrTextObj::SdrTextObj(
const tools::Rectangle& rNewRect)
: SdrAttrObj(rSdrModel),
maRect(rNewRect),
- pEdtOutl(nullptr),
- eTextKind(OBJ_TEXT)
+ mpEdtOutl(nullptr),
+ meTextKind(OBJ_TEXT)
{
- bTextSizeDirty=false;
- bTextFrame=false;
- bNoShear=false;
- bDisableAutoWidthOnDragging=false;
+ mbTextSizeDirty = false;
+ mbTextFrame = false;
+ mbNoShear = false;
+ mbDisableAutoWidthOnDragging = false;
ImpJustifyRect(maRect);
mbInEditMode = false;
@@ -162,13 +162,13 @@ SdrTextObj::SdrTextObj(
SdrModel& rSdrModel,
SdrObjKind eNewTextKind)
: SdrAttrObj(rSdrModel),
- pEdtOutl(nullptr),
- eTextKind(eNewTextKind)
+ mpEdtOutl(nullptr),
+ meTextKind(eNewTextKind)
{
- bTextSizeDirty=false;
- bTextFrame=true;
- bNoShear=true;
- bDisableAutoWidthOnDragging=false;
+ mbTextSizeDirty = false;
+ mbTextFrame = true;
+ mbNoShear = true;
+ mbDisableAutoWidthOnDragging = false;
mbInEditMode = false;
mbTextAnimationAllowed = true;
@@ -185,13 +185,13 @@ SdrTextObj::SdrTextObj(
const tools::Rectangle& rNewRect)
: SdrAttrObj(rSdrModel),
maRect(rNewRect),
- pEdtOutl(nullptr),
- eTextKind(eNewTextKind)
+ mpEdtOutl(nullptr),
+ meTextKind(eNewTextKind)
{
- bTextSizeDirty=false;
- bTextFrame=true;
- bNoShear=true;
- bDisableAutoWidthOnDragging=false;
+ mbTextSizeDirty = false;
+ mbTextFrame = true;
+ mbNoShear = true;
+ mbDisableAutoWidthOnDragging = false;
ImpJustifyRect(maRect);
mbInEditMode = false;
@@ -244,11 +244,11 @@ void SdrTextObj::NbcSetText(const OUString& rStr)
rOutliner.SetUpdateMode(true);
rOutliner.SetText(rStr,rOutliner.GetParagraph( 0 ));
std::unique_ptr<OutlinerParaObject> pNewText=rOutliner.CreateParaObject();
- Size aSiz(rOutliner.CalcTextSize());
+ Size aSize(rOutliner.CalcTextSize());
rOutliner.Clear();
NbcSetOutlinerParaObject(std::move(pNewText));
- aTextSize=aSiz;
- bTextSizeDirty=false;
+ maTextSize = aSize;
+ mbTextSizeDirty=false;
}
void SdrTextObj::SetText(const OUString& rStr)
@@ -267,11 +267,11 @@ void SdrTextObj::NbcSetText(SvStream& rInput, const OUString& rBaseURL, EETextFo
rOutliner.Read(rInput,rBaseURL,eFormat);
std::unique_ptr<OutlinerParaObject> pNewText=rOutliner.CreateParaObject();
rOutliner.SetUpdateMode(true);
- Size aSiz(rOutliner.CalcTextSize());
+ Size aSize(rOutliner.CalcTextSize());
rOutliner.Clear();
NbcSetOutlinerParaObject(std::move(pNewText));
- aTextSize=aSiz;
- bTextSizeDirty=false;
+ maTextSize=aSize;
+ mbTextSizeDirty=false;
}
void SdrTextObj::SetText(SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat)
@@ -285,7 +285,7 @@ void SdrTextObj::SetText(SvStream& rInput, const OUString& rBaseURL, EETextForma
const Size& SdrTextObj::GetTextSize() const
{
- if (bTextSizeDirty)
+ if (mbTextSizeDirty)
{
Size aSiz;
SdrText* pText = getActiveText();
@@ -298,15 +298,15 @@ const Size& SdrTextObj::GetTextSize() const
rOutliner.Clear();
}
// casting to nonconst twice
- const_cast<SdrTextObj*>(this)->aTextSize=aSiz;
- const_cast<SdrTextObj*>(this)->bTextSizeDirty=false;
+ const_cast<SdrTextObj*>(this)->maTextSize = aSiz;
+ const_cast<SdrTextObj*>(this)->mbTextSizeDirty = false;
}
- return aTextSize;
+ return maTextSize;
}
bool SdrTextObj::IsAutoGrowHeight() const
{
- if(!bTextFrame)
+ if(!mbTextFrame)
return false; // AutoGrow only together with TextFrames
const SfxItemSet& rSet = GetObjectItemSet();
@@ -331,7 +331,7 @@ bool SdrTextObj::IsAutoGrowHeight() const
bool SdrTextObj::IsAutoGrowWidth() const
{
- if(!bTextFrame)
+ if (!mbTextFrame)
return false; // AutoGrow only together with TextFrames
const SfxItemSet& rSet = GetObjectItemSet();
@@ -432,16 +432,17 @@ void SdrTextObj::ImpJustifyRect(tools::Rectangle& rRect)
void SdrTextObj::ImpCheckShear()
{
- if (bNoShear && aGeo.nShearAngle) {
- aGeo.nShearAngle=0_deg100;
- aGeo.mfTanShearAngle=0;
+ if (mbNoShear && maGeo.nShearAngle)
+ {
+ maGeo.nShearAngle = 0_deg100;
+ maGeo.mfTanShearAngle = 0;
}
}
void SdrTextObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
{
bool bNoTextFrame=!IsTextFrame();
- rInfo.bResizeFreeAllowed=bNoTextFrame || ((aGeo.nRotationAngle.get() % 9000) == 0);
+ rInfo.bResizeFreeAllowed=bNoTextFrame || ((maGeo.nRotationAngle.get() % 9000) == 0);
rInfo.bResizePropAllowed=true;
rInfo.bRotateFreeAllowed=true;
rInfo.bRotate90Allowed =true;
@@ -464,7 +465,7 @@ void SdrTextObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
SdrObjKind SdrTextObj::GetObjIdentifier() const
{
- return eTextKind;
+ return meTextKind;
}
bool SdrTextObj::HasTextImpl( SdrOutliner const * pOutliner )
@@ -518,7 +519,7 @@ void SdrTextObj::NbcSetEckenradius(tools::Long nRad)
// states of IsAutoGrowWidth/Height to correctly set TextMinFrameWidth/Height
void SdrTextObj::AdaptTextMinSize()
{
- if (!bTextFrame)
+ if (!mbTextFrame)
// Only do this for text frame.
return;
@@ -546,9 +547,9 @@ void SdrTextObj::AdaptTextMinSize()
aSet.Put(makeSdrTextMinFrameWidthItem(nW));
- if(!IsVerticalWriting() && bDisableAutoWidthOnDragging)
+ if(!IsVerticalWriting() && mbDisableAutoWidthOnDragging)
{
- bDisableAutoWidthOnDragging = true;
+ mbDisableAutoWidthOnDragging = true;
aSet.Put(makeSdrTextAutoGrowWidthItem(false));
}
}
@@ -561,9 +562,9 @@ void SdrTextObj::AdaptTextMinSize()
aSet.Put(makeSdrTextMinFrameHeightItem(nH));
- if(IsVerticalWriting() && bDisableAutoWidthOnDragging)
+ if(IsVerticalWriting() && mbDisableAutoWidthOnDragging)
{
- bDisableAutoWidthOnDragging = false;
+ mbDisableAutoWidthOnDragging = false;
aSet.Put(makeSdrTextAutoGrowHeightItem(false));
}
}
@@ -578,10 +579,10 @@ void SdrTextObj::ImpSetContourPolygon( SdrOutliner& rOutliner, tools::Rectangle
basegfx::B2DHomMatrix aMatrix(basegfx::utils::createTranslateB2DHomMatrix(
-rAnchorRect.Left(), -rAnchorRect.Top()));
- if(aGeo.nRotationAngle)
+ if(maGeo.nRotationAngle)
{
// Unrotate!
- aMatrix.rotate(-aGeo.nRotationAngle.get() * F_PI18000);
+ aMatrix.rotate(-maGeo.nRotationAngle.get() * F_PI18000);
}
aXorPolyPolygon.transform(aMatrix);
@@ -659,9 +660,9 @@ void SdrTextObj::TakeTextAnchorRect(tools::Rectangle& rAnchorRect) const
if (aAnkRect.GetWidth()<2) aAnkRect.SetRight(aAnkRect.Left()+1 ); // minimum size h and v: 2 px
if (aAnkRect.GetHeight()<2) aAnkRect.SetBottom(aAnkRect.Top()+1 );
}
- if (aGeo.nRotationAngle) {
+ if (maGeo.nRotationAngle) {
Point aTmpPt(aAnkRect.TopLeft());
- RotatePoint(aTmpPt,aRotateRef,aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aTmpPt,aRotateRef,maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aTmpPt-=aAnkRect.TopLeft();
aAnkRect.Move(aTmpPt.X(),aTmpPt.Y());
}
@@ -749,7 +750,7 @@ void SdrTextObj::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle& rTextRe
// put text into the outliner, if available from the edit outliner
SdrText* pText = getActiveText();
OutlinerParaObject* pOutlinerParaObject = pText ? pText->GetOutlinerParaObject() : nullptr;
- OutlinerParaObject* pPara = (pEdtOutl && !bNoEditText) ? pEdtOutl->CreateParaObject().release() : pOutlinerParaObject;
+ OutlinerParaObject* pPara = (mpEdtOutl && !bNoEditText) ? mpEdtOutl->CreateParaObject().release() : pOutlinerParaObject;
if (pPara)
{
@@ -774,7 +775,7 @@ void SdrTextObj::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle& rTextRe
rOutliner.SetTextObj( nullptr );
}
- if (pEdtOutl && !bNoEditText && pPara)
+ if (mpEdtOutl && !bNoEditText && pPara)
delete pPara;
rOutliner.SetUpdateMode(true);
@@ -828,8 +829,8 @@ void SdrTextObj::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle& rTextRe
if (eVAdj==SDRTEXTVERTADJUST_BOTTOM)
aTextPos.AdjustY(nFreeHgt );
}
- if (aGeo.nRotationAngle)
- RotatePoint(aTextPos,aAnkRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ RotatePoint(aTextPos,aAnkRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
if (pAnchorRect)
*pAnchorRect=aAnkRect;
@@ -842,9 +843,9 @@ void SdrTextObj::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle& rTextRe
bool SdrTextObj::CanCreateEditOutlinerParaObject() const
{
- if( HasTextImpl( pEdtOutl ) )
+ if( HasTextImpl( mpEdtOutl ) )
{
- return pEdtOutl->GetParagraphCount() > 0;
+ return mpEdtOutl->GetParagraphCount() > 0;
}
return false;
}
@@ -852,10 +853,10 @@ bool SdrTextObj::CanCreateEditOutlinerParaObject() const
std::unique_ptr<OutlinerParaObject> SdrTextObj::CreateEditOutlinerParaObject() const
{
std::unique_ptr<OutlinerParaObject> pPara;
- if( HasTextImpl( pEdtOutl ) )
+ if( HasTextImpl( mpEdtOutl ) )
{
- sal_Int32 nParaCount = pEdtOutl->GetParagraphCount();
- pPara = pEdtOutl->CreateParaObject(0, nParaCount);
+ sal_Int32 nParaCount = mpEdtOutl->GetParagraphCount();
+ pPara = mpEdtOutl->CreateParaObject(0, nParaCount);
}
return pPara;
}
@@ -974,7 +975,7 @@ OUString SdrTextObj::TakeObjNameSingul() const
{
OUString aStr;
- switch(eTextKind)
+ switch(meTextKind)
{
case OBJ_OUTLINETEXT:
{
@@ -999,7 +1000,7 @@ OUString SdrTextObj::TakeObjNameSingul() const
}
OutlinerParaObject* pOutlinerParaObject = GetOutlinerParaObject();
- if(pOutlinerParaObject && eTextKind != OBJ_OUTLINETEXT)
+ if(pOutlinerParaObject && meTextKind != OBJ_OUTLINETEXT)
{
// shouldn't currently cause any problems at OUTLINETEXT
OUString aStr2(comphelper::string::stripStart(pOutlinerParaObject->GetTextObject().GetText(0), ' '));
@@ -1032,7 +1033,8 @@ OUString SdrTextObj::TakeObjNameSingul() const
OUString SdrTextObj::TakeObjNamePlural() const
{
OUString sName;
- switch (eTextKind) {
+ switch (meTextKind)
+ {
case OBJ_OUTLINETEXT: sName=SvxResId(STR_ObjNamePluralOUTLINETEXT); break;
case OBJ_TITLETEXT : sName=SvxResId(STR_ObjNamePluralTITLETEXT); break;
default: {
@@ -1054,8 +1056,8 @@ SdrTextObj* SdrTextObj::CloneSdrObject(SdrModel& rTargetModel) const
basegfx::B2DPolyPolygon SdrTextObj::TakeXorPoly() const
{
tools::Polygon aPol(maRect);
- if (aGeo.nShearAngle) ShearPoly(aPol,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoly(aPol,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoly(aPol,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoly(aPol,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
basegfx::B2DPolyPolygon aRetval;
aRetval.append(aPol.getB2DPolygon());
@@ -1081,7 +1083,7 @@ basegfx::B2DPolyPolygon SdrTextObj::TakeContour() const
bool bFitToSize(IsFitToSize());
if (bFitToSize) aR=aAnchor2;
tools::Polygon aPol(aR);
- if (aGeo.nRotationAngle) RotatePoly(aPol,aR.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle) RotatePoly(aPol,aR.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aRetval.append(aPol.getB2DPolygon());
}
@@ -1091,11 +1093,11 @@ basegfx::B2DPolyPolygon SdrTextObj::TakeContour() const
void SdrTextObj::RecalcSnapRect()
{
- if (aGeo.nRotationAngle || aGeo.nShearAngle)
+ if (maGeo.nRotationAngle || maGeo.nShearAngle)
{
tools::Polygon aPol(maRect);
- if (aGeo.nShearAngle) ShearPoly(aPol,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoly(aPol,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoly(aPol,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoly(aPol,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
maSnapRect=aPol.GetBoundRect();
} else {
maSnapRect = maRect;
@@ -1117,8 +1119,8 @@ Point SdrTextObj::GetSnapPoint(sal_uInt32 i) const
case 3: aP=maRect.BottomRight(); break;
default: aP=maRect.Center(); break;
}
- if (aGeo.nShearAngle) ShearPoint(aP,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoint(aP,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoint(aP,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoint(aP,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
return aP;
}
@@ -1361,7 +1363,7 @@ void SdrTextObj::NbcReformatText()
return;
pText->ReformatText();
- if (bTextFrame)
+ if (mbTextFrame)
{
NbcAdjustTextFrameWidthAndHeight();
}
@@ -1390,16 +1392,16 @@ void SdrTextObj::SaveGeoData(SdrObjGeoData& rGeo) const
{
SdrAttrObj::SaveGeoData(rGeo);
SdrTextObjGeoData& rTGeo=static_cast<SdrTextObjGeoData&>(rGeo);
- rTGeo.aRect = maRect;
- rTGeo.aGeo =aGeo;
+ rTGeo.maRect = maRect;
+ rTGeo.maGeo = maGeo;
}
void SdrTextObj::RestoreGeoData(const SdrObjGeoData& rGeo)
{ // RectsDirty is called by SdrObject
SdrAttrObj::RestoreGeoData(rGeo);
const SdrTextObjGeoData& rTGeo=static_cast<const SdrTextObjGeoData&>(rGeo);
- NbcSetLogicRect(rTGeo.aRect);
- aGeo =rTGeo.aGeo;
+ NbcSetLogicRect(rTGeo.maRect);
+ maGeo = rTGeo.maGeo;
SetTextSizeDirty();
}
@@ -1424,7 +1426,7 @@ void SdrTextObj::ForceOutlinerParaObject()
if( pText && (pText->GetOutlinerParaObject() == nullptr) )
{
OutlinerMode nOutlMode = OutlinerMode::TextObject;
- if( IsTextFrame() && eTextKind == OBJ_OUTLINETEXT )
+ if( IsTextFrame() && meTextKind == OBJ_OUTLINETEXT )
nOutlMode = OutlinerMode::OutlineObject;
pText->ForceOutlinerParaObject( nOutlMode );
@@ -1441,9 +1443,9 @@ TextChain *SdrTextObj::GetTextChain() const
bool SdrTextObj::IsVerticalWriting() const
{
- if(pEdtOutl)
+ if(mpEdtOutl)
{
- return pEdtOutl->IsVertical();
+ return mpEdtOutl->IsVertical();
}
OutlinerParaObject* pOutlinerParaObject = GetOutlinerParaObject();
@@ -1534,8 +1536,8 @@ void SdrTextObj::SetVerticalWriting(bool bVertical)
bool SdrTextObj::TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegfx::B2DPolyPolygon& /*rPolyPolygon*/) const
{
// get turn and shear
- double fRotate = basegfx::deg2rad(aGeo.nRotationAngle.get() / 100.0);
- double fShearX = basegfx::deg2rad(aGeo.nShearAngle.get() / 100.0);
+ double fRotate = basegfx::deg2rad(maGeo.nRotationAngle.get() / 100.0);
+ double fShearX = basegfx::deg2rad(maGeo.nShearAngle.get() / 100.0);
// get aRect, this is the unrotated snaprect
tools::Rectangle aRectangle(maRect);
@@ -1588,10 +1590,10 @@ void SdrTextObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
}
// reset object shear and rotations
- aGeo.nRotationAngle = 0_deg100;
- aGeo.RecalcSinCos();
- aGeo.nShearAngle = 0_deg100;
- aGeo.RecalcTan();
+ maGeo.nRotationAngle = 0_deg100;
+ maGeo.RecalcSinCos();
+ maGeo.nShearAngle = 0_deg100;
+ maGeo.RecalcTan();
// if anchor is used, make position relative to it
if( getSdrModelFromSdrObject().IsWriter() )
@@ -1648,7 +1650,7 @@ void SdrTextObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
bool SdrTextObj::IsReallyEdited() const
{
- return pEdtOutl && pEdtOutl->IsModified();
+ return mpEdtOutl && mpEdtOutl->IsModified();
}
// moved inlines here form hxx
@@ -1680,19 +1682,19 @@ tools::Long SdrTextObj::GetMaxTextFrameWidth() const
bool SdrTextObj::IsFontwork() const
{
- return !bTextFrame // Default is FALSE
+ return !mbTextFrame // Default is FALSE
&& GetObjectItemSet().Get(XATTR_FORMTXTSTYLE).GetValue() != XFormTextStyle::NONE;
}
bool SdrTextObj::IsHideContour() const
{
- return !bTextFrame // Default is: no, don't HideContour; HideContour not together with TextFrames
+ return !mbTextFrame // Default is: no, don't HideContour; HideContour not together with TextFrames
&& GetObjectItemSet().Get(XATTR_FORMTXTHIDEFORM).GetValue();
}
bool SdrTextObj::IsContourTextFrame() const
{
- return !bTextFrame // ContourFrame not together with normal TextFrames
+ return !mbTextFrame // ContourFrame not together with normal TextFrames
&& GetObjectItemSet().Get(SDRATTR_TEXT_CONTOURFRAME).GetValue();
}
@@ -1771,10 +1773,10 @@ GDIMetaFile* SdrTextObj::GetTextScrollMetaFileAndRectangle(
// get outliner set up. To avoid getting a somehow rotated MetaFile,
// temporarily disable object rotation.
- Degree100 nAngle(aGeo.nRotationAngle);
- aGeo.nRotationAngle = 0_deg100;
+ Degree100 nAngle(maGeo.nRotationAngle);
+ maGeo.nRotationAngle = 0_deg100;
ImpSetupDrawOutlinerForPaint( bContourFrame, rOutliner, aTextRect, aAnchorRect, aPaintRect, aFitXCorrection );
- aGeo.nRotationAngle = nAngle;
+ maGeo.nRotationAngle = nAngle;
tools::Rectangle aScrollFrameRect(aPaintRect);
const SfxItemSet& rSet = GetObjectItemSet();
@@ -1839,7 +1841,7 @@ void SdrTextObj::onEditOutlinerStatusEvent( EditStatus* pEditStatus )
const EditStatusFlags nStat = pEditStatus->GetStatusWord();
const bool bGrowX = bool(nStat & EditStatusFlags::TEXTWIDTHCHANGED);
const bool bGrowY = bool(nStat & EditStatusFlags::TextHeightChanged);
- if(!(bTextFrame && (bGrowX || bGrowY)))
+ if(!(mbTextFrame && (bGrowX || bGrowY)))
return;
if ((bGrowX && IsAutoGrowWidth()) || (bGrowY && IsAutoGrowHeight()))
@@ -1848,13 +1850,13 @@ void SdrTextObj::onEditOutlinerStatusEvent( EditStatus* pEditStatus )
}
else if ( (IsAutoFit() || IsFitToSize()) && !mbInDownScale)
{
- assert(pEdtOutl);
+ assert(mpEdtOutl);
mbInDownScale = true;
// sucks that we cannot disable paints via
- // pEdtOutl->SetUpdateMode(FALSE) - but EditEngine skips
+ // mpEdtOutl->SetUpdateMode(FALSE) - but EditEngine skips
// formatting as well, then.
- ImpAutoFitText(*pEdtOutl);
+ ImpAutoFitText(*mpEdtOutl);
mbInDownScale = false;
}
}
@@ -1925,20 +1927,20 @@ bool SdrTextObj::IsChainable() const
void SdrTextObj::onChainingEvent()
{
- if (!pEdtOutl)
+ if (!mpEdtOutl)
return;
// Outliner for text transfer
SdrOutliner &aDrawOutliner = ImpGetDrawOutliner();
EditingTextChainFlow aTxtChainFlow(this);
- aTxtChainFlow.CheckForFlowEvents(pEdtOutl);
+ aTxtChainFlow.CheckForFlowEvents(mpEdtOutl);
if (aTxtChainFlow.IsOverflow()) {
SAL_INFO("svx.chaining", "[CHAINING] Overflow going on");
// One outliner is for non-overflowing text, the other for overflowing text
// We remove text directly from the editing outliner
- aTxtChainFlow.ExecuteOverflow(pEdtOutl, &aDrawOutliner);
+ aTxtChainFlow.ExecuteOverflow(mpEdtOutl, &aDrawOutliner);
} else if (aTxtChainFlow.IsUnderflow()) {
SAL_INFO("svx.chaining", "[CHAINING] Underflow going on");
// underflow-induced overflow
@@ -2085,8 +2087,8 @@ void SdrTextObj::SetObjectItemNoBroadcast(const SfxPoolItem& rItem)
// - enum vertical text anchoring top, middle, bottom, block, stretch(ni)
// - enum ticker text (if it is not FontWork)
-// Every derived object is either a text frame (bTextFrame=true)
-// or a drawing object with a caption (bTextFrame=false).
+// Every derived object is either a text frame (mbTextFrame=true)
+// or a drawing object with a caption (mbTextFrame=false).
// Default anchoring for text frames:
// SDRTEXTHORZADJUST_BLOCK, SDRTEXTVERTADJUST_TOP
@@ -2097,7 +2099,7 @@ void SdrTextObj::SetObjectItemNoBroadcast(const SfxPoolItem& rItem)
// Every object derived from SdrTextObj must return an "UnrotatedSnapRect"
// (->TakeUnrotatedSnapRect()) (the reference point for the rotation is the top
-// left of the rectangle (aGeo.nRotationAngle)) which is the basis for anchoring
+// left of the rectangle (maGeo.nRotationAngle)) which is the basis for anchoring
// text. We then subtract the text frame margins from this rectangle, as a re-
// sult we get the anchoring area (->TakeTextAnchorRect()). Within this area, we
// calculate the anchoring point and the painting area, depending on the hori-
diff --git a/svx/source/svdraw/svdotxat.cxx b/svx/source/svdraw/svdotxat.cxx
index a509ac290ccf..d9f5c6833779 100644
--- a/svx/source/svdraw/svdotxat.cxx
+++ b/svx/source/svdraw/svdotxat.cxx
@@ -41,7 +41,7 @@ const char PADDING_CHARACTER_FOR_STYLE_FAMILY = ' ';
bool SdrTextObj::AdjustTextFrameWidthAndHeight( tools::Rectangle& rR, bool bHgt, bool bWdt ) const
{
- if (!bTextFrame)
+ if (!mbTextFrame)
// Not a text frame. Bail out.
return false;
@@ -123,19 +123,19 @@ bool SdrTextObj::AdjustTextFrameWidthAndHeight( tools::Rectangle& rR, bool bHgt,
aNewSize.setHeight( 0x0FFFFFFF );
}
- if (pEdtOutl)
+ if (mpEdtOutl)
{
- pEdtOutl->SetMaxAutoPaperSize(aNewSize);
+ mpEdtOutl->SetMaxAutoPaperSize(aNewSize);
if (bWdtGrow)
{
- Size aSiz2(pEdtOutl->CalcTextSize());
+ Size aSiz2(mpEdtOutl->CalcTextSize());
nWdt = aSiz2.Width() + 1; // a little tolerance
if (bHgtGrow)
nHgt = aSiz2.Height() + 1; // a little tolerance
}
else
{
- nHgt = pEdtOutl->GetTextHeight() + 1; // a little tolerance
+ nHgt = mpEdtOutl->GetTextHeight() + 1; // a little tolerance
}
}
else
@@ -222,13 +222,13 @@ bool SdrTextObj::AdjustTextFrameWidthAndHeight( tools::Rectangle& rR, bool bHgt,
}
}
- if (aGeo.nRotationAngle)
+ if (maGeo.nRotationAngle)
{
// Object is rotated.
Point aD1(rR.TopLeft());
aD1 -= aOldRect.TopLeft();
Point aD2(aD1);
- RotatePoint(aD2, Point(), aGeo.mfSinRotationAngle, aGeo.mfCosRotationAngle);
+ RotatePoint(aD2, Point(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aD2 -= aD1;
rR.Move(aD2.X(), aD2.Y());
}
@@ -387,8 +387,8 @@ void SdrTextObj::RemoveOutlinerCharacterAttribs( const std::vector<sal_uInt16>&
{
Outliner* pOutliner = nullptr;
- if( pEdtOutl || (pText == getActiveText()) )
- pOutliner = pEdtOutl;
+ if( mpEdtOutl || (pText == getActiveText()) )
+ pOutliner = mpEdtOutl;
if(!pOutliner)
{
@@ -402,7 +402,7 @@ void SdrTextObj::RemoveOutlinerCharacterAttribs( const std::vector<sal_uInt16>&
pOutliner->RemoveAttribs( aSelAll, false, rWhichId );
}
- if(!pEdtOutl || (pText != getActiveText()) )
+ if(!mpEdtOutl || (pText != getActiveText()) )
{
const sal_Int32 nParaCount = pOutliner->GetParagraphCount();
std::unique_ptr<OutlinerParaObject> pTemp = pOutliner->CreateParaObject(0, nParaCount);
@@ -415,8 +415,8 @@ void SdrTextObj::RemoveOutlinerCharacterAttribs( const std::vector<sal_uInt16>&
bool SdrTextObj::HasText() const
{
- if( pEdtOutl )
- return HasTextImpl(pEdtOutl);
+ if (mpEdtOutl)
+ return HasTextImpl(mpEdtOutl);
OutlinerParaObject* pOPO = GetOutlinerParaObject();
diff --git a/svx/source/svdraw/svdotxdr.cxx b/svx/source/svdraw/svdotxdr.cxx
index 0d881c80041f..4ea2b7edbf2b 100644
--- a/svx/source/svdraw/svdotxdr.cxx
+++ b/svx/source/svdraw/svdotxdr.cxx
@@ -54,11 +54,11 @@ void SdrTextObj::AddToHdlList(SdrHdlList& rHdlList) const
case 6: aPnt=maRect.BottomCenter(); eKind=SdrHdlKind::Lower; break;
case 7: aPnt=maRect.BottomRight(); eKind=SdrHdlKind::LowerRight; break;
}
- if (aGeo.nShearAngle) ShearPoint(aPnt,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle) RotatePoint(aPnt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle) ShearPoint(aPnt,maRect.TopLeft(),maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle) RotatePoint(aPnt,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
std::unique_ptr<SdrHdl> pH(new SdrHdl(aPnt,eKind));
pH->SetObj(const_cast<SdrTextObj*>(this));
- pH->SetRotationAngle(aGeo.nRotationAngle);
+ pH->SetRotationAngle(maGeo.nRotationAngle);
rHdlList.AddHdl(std::move(pH));
}
}
@@ -79,9 +79,9 @@ tools::Rectangle SdrTextObj::ImpDragCalcRect(const SdrDragStat& rDrag) const
bool bBigOrtho=bEcke && bOrtho && rDrag.GetView()->IsBigOrtho();
Point aPos(rDrag.GetNow());
// Unrotate:
- if (aGeo.nRotationAngle) RotatePoint(aPos,aTmpRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle) RotatePoint(aPos,aTmpRect.TopLeft(),-maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
// Unshear:
- if (aGeo.nShearAngle) ShearPoint(aPos,aTmpRect.TopLeft(),-aGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle) ShearPoint(aPos,aTmpRect.TopLeft(),-maGeo.mfTanShearAngle);
bool bLft=(eHdl==SdrHdlKind::UpperLeft || eHdl==SdrHdlKind::Left || eHdl==SdrHdlKind::LowerLeft);
bool bRgt=(eHdl==SdrHdlKind::UpperRight || eHdl==SdrHdlKind::Right || eHdl==SdrHdlKind::LowerRight);
@@ -150,15 +150,15 @@ bool SdrTextObj::applySpecialDrag(SdrDragStat& rDrag)
{
tools::Rectangle aNewRect(ImpDragCalcRect(rDrag));
- if(aNewRect.TopLeft() != maRect.TopLeft() && (aGeo.nRotationAngle || aGeo.nShearAngle))
+ if(aNewRect.TopLeft() != maRect.TopLeft() && (maGeo.nRotationAngle || maGeo.nShearAngle))
{
Point aNewPos(aNewRect.TopLeft());
- if(aGeo.nShearAngle)
- ShearPoint(aNewPos,maRect.TopLeft(),aGeo.mfTanShearAngle);
+ if (maGeo.nShearAngle)
+ ShearPoint(aNewPos,maRect.TopLeft(),maGeo.mfTanShearAngle);
- if(aGeo.nRotationAngle)
- RotatePoint(aNewPos,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle)
+ RotatePoint(aNewPos,maRect.TopLeft(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aNewRect.SetPos(aNewPos);
}
diff --git a/svx/source/svdraw/svdotxed.cxx b/svx/source/svdraw/svdotxed.cxx
index 950a5cff85be..13c4440c0d77 100644
--- a/svx/source/svdraw/svdotxed.cxx
+++ b/svx/source/svdraw/svdotxed.cxx
@@ -39,8 +39,8 @@ bool SdrTextObj::HasTextEdit() const
bool SdrTextObj::BegTextEdit(SdrOutliner& rOutl)
{
- if (pEdtOutl!=nullptr) return false; // Textedit might already run in another View!
- pEdtOutl=&rOutl;
+ if (mpEdtOutl!=nullptr) return false; // Textedit might already run in another View!
+ mpEdtOutl=&rOutl;
mbInEditMode = true;
@@ -115,7 +115,7 @@ bool SdrTextObj::BegTextEdit(SdrOutliner& rOutl)
if(pOutlinerParaObject)
{
- if(aGeo.nRotationAngle || IsFontwork())
+ if (maGeo.nRotationAngle || IsFontwork())
{
// only repaint here, no real objectchange
BroadcastObjectChange();
@@ -134,11 +134,11 @@ void SdrTextObj::TakeTextEditArea(Size* pPaperMin, Size* pPaperMax, tools::Recta
Size aPaperMin,aPaperMax;
tools::Rectangle aViewInit;
TakeTextAnchorRect(aViewInit);
- if (aGeo.nRotationAngle) {
+ if (maGeo.nRotationAngle) {
Point aCenter(aViewInit.Center());
aCenter-=aViewInit.TopLeft();
Point aCenter0(aCenter);
- RotatePoint(aCenter,Point(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aCenter,Point(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aCenter-=aCenter0;
aViewInit.Move(aCenter.X(),aCenter.Y());
}
@@ -291,7 +291,7 @@ void SdrTextObj::EndTextEdit(SdrOutliner& rOutl)
/* Chaining-related code */
rOutl.ClearOverflowingParaNum();
- pEdtOutl = nullptr;
+ mpEdtOutl = nullptr;
rOutl.Clear();
EEControlBits nStat = rOutl.GetControlWord();
nStat &= ~EEControlBits::AUTOPAGESIZE;
@@ -336,26 +336,26 @@ EEAnchorMode SdrTextObj::GetOutlinerViewAnchorMode() const
void SdrTextObj::ImpSetTextEditParams() const
{
- if (pEdtOutl==nullptr)
+ if (mpEdtOutl==nullptr)
return;
- bool bUpdBuf=pEdtOutl->GetUpdateMode();
- if (bUpdBuf) pEdtOutl->SetUpdateMode(false);
+ bool bUpdBuf=mpEdtOutl->GetUpdateMode();
+ if (bUpdBuf) mpEdtOutl->SetUpdateMode(false);
Size aPaperMin;
Size aPaperMax;
tools::Rectangle aEditArea;
TakeTextEditArea(&aPaperMin,&aPaperMax,&aEditArea,nullptr);
bool bContourFrame=IsContourTextFrame();
- pEdtOutl->SetMinAutoPaperSize(aPaperMin);
- pEdtOutl->SetMaxAutoPaperSize(aPaperMax);
- pEdtOutl->SetPaperSize(Size());
- pEdtOutl->SetTextColumns(GetTextColumnsNumber(), GetTextColumnsSpacing());
+ mpEdtOutl->SetMinAutoPaperSize(aPaperMin);
+ mpEdtOutl->SetMaxAutoPaperSize(aPaperMax);
+ mpEdtOutl->SetPaperSize(Size());
+ mpEdtOutl->SetTextColumns(GetTextColumnsNumber(), GetTextColumnsSpacing());
if (bContourFrame) {
tools::Rectangle aAnchorRect;
TakeTextAnchorRect(aAnchorRect);
- ImpSetContourPolygon(*pEdtOutl,aAnchorRect, true);
+ ImpSetContourPolygon(*mpEdtOutl,aAnchorRect, true);
}
- if (bUpdBuf) pEdtOutl->SetUpdateMode(true);
+ if (bUpdBuf) mpEdtOutl->SetUpdateMode(true);
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/svx/source/svdraw/svdotxln.cxx b/svx/source/svdraw/svdotxln.cxx
index 01055b45afb6..19953dcc6942 100644
--- a/svx/source/svdraw/svdotxln.cxx
+++ b/svx/source/svdraw/svdotxln.cxx
@@ -56,7 +56,7 @@ void ImpSdrObjTextLink::Closed()
{
// set pLink of the object to NULL, because we are destroying the link instance now
ImpSdrObjTextLinkUserData* pData=pSdrObj->GetLinkUserData();
- if (pData!=nullptr) pData->pLink=nullptr;
+ if (pData!=nullptr) pData->mpLink = nullptr;
pSdrObj->ReleaseTextLink();
}
SvBaseLink::Closed();
@@ -79,11 +79,11 @@ void ImpSdrObjTextLink::Closed()
OUString aFilter;
sfx2::LinkManager::GetDisplayNames( this, nullptr,&aFile, nullptr, &aFilter );
- if( pData->aFileName != aFile ||
- pData->aFilterName != aFilter )
+ if( pData->maFileName != aFile ||
+ pData->maFilterName != aFilter )
{
- pData->aFileName = aFile;
- pData->aFilterName = aFilter;
+ pData->maFileName = aFile;
+ pData->maFilterName = aFilter;
pSdrObj->SetChanged();
bForceReload = true;
}
@@ -98,8 +98,8 @@ void ImpSdrObjTextLink::Closed()
ImpSdrObjTextLinkUserData::ImpSdrObjTextLinkUserData():
SdrObjUserData(SdrInventor::Default,SDRUSERDATA_OBJTEXTLINK),
- aFileDate0( DateTime::EMPTY ),
- eCharSet(RTL_TEXTENCODING_DONTKNOW)
+ maFileDate0( DateTime::EMPTY ),
+ meCharSet(RTL_TEXTENCODING_DONTKNOW)
{
}
@@ -109,12 +109,12 @@ ImpSdrObjTextLinkUserData::~ImpSdrObjTextLinkUserData()
std::unique_ptr<SdrObjUserData> ImpSdrObjTextLinkUserData::Clone(SdrObject* ) const
{
- ImpSdrObjTextLinkUserData* pData=new ImpSdrObjTextLinkUserData;
- pData->aFileName =aFileName;
- pData->aFilterName=aFilterName;
- pData->aFileDate0 =aFileDate0;
- pData->eCharSet =eCharSet;
- pData->pLink=nullptr;
+ ImpSdrObjTextLinkUserData* pData = new ImpSdrObjTextLinkUserData;
+ pData->maFileName = maFileName;
+ pData->maFilterName = maFilterName;
+ pData->maFileDate0 = maFileDate0;
+ pData->meCharSet = meCharSet;
+ pData->mpLink = nullptr;
return std::unique_ptr<SdrObjUserData>(pData);
}
@@ -128,9 +128,9 @@ void SdrTextObj::SetTextLink(const OUString& rFileName, const OUString& rFilterN
ReleaseTextLink();
}
pData=new ImpSdrObjTextLinkUserData;
- pData->aFileName=rFileName;
- pData->aFilterName=rFilterName;
- pData->eCharSet=eCharSet;
+ pData->maFileName = rFileName;
+ pData->maFilterName = rFilterName;
+ pData->meCharSet = eCharSet;
AppendUserData(std::unique_ptr<SdrObjUserData>(pData));
ImpRegisterLink();
}
@@ -160,7 +160,7 @@ bool SdrTextObj::ReloadLinkedText( bool bForceLoad)
try
{
- INetURLObject aURL( pData->aFileName );
+ INetURLObject aURL( pData->maFileName );
DBG_ASSERT( aURL.GetProtocol() != INetProtocol::NotValid, "invalid URL" );
::ucbhelper::Content aCnt( aURL.GetMainURL( INetURLObject::DecodeMechanism::NONE ), css::uno::Reference< css::ucb::XCommandEnvironment >(), comphelper::getProcessComponentContext() );
@@ -181,14 +181,14 @@ bool SdrTextObj::ReloadLinkedText( bool bForceLoad)
if( bForceLoad )
bLoad = true;
else
- bLoad = ( aFileDT > pData->aFileDate0 );
+ bLoad = ( aFileDT > pData->maFileDate0 );
if( bLoad )
{
- bRet = LoadText( pData->aFileName, pData->eCharSet );
+ bRet = LoadText( pData->maFileName, pData->meCharSet );
}
- pData->aFileDate0 = aFileDT;
+ pData->maFileDate0 = aFileDT;
}
}
@@ -255,11 +255,11 @@ void SdrTextObj::ImpRegisterLink()
{
ImpSdrObjTextLinkUserData* pData=GetLinkUserData();
sfx2::LinkManager* pLinkManager(getSdrModelFromSdrObject().GetLinkManager());
- if (pLinkManager!=nullptr && pData!=nullptr && pData->pLink==nullptr) { // don't register twice
- pData->pLink = new ImpSdrObjTextLink(this);
- pLinkManager->InsertFileLink(*pData->pLink,sfx2::SvBaseLinkObjectType::ClientFile,pData->aFileName,
- !pData->aFilterName.isEmpty() ?
- &pData->aFilterName : nullptr);
+ if (pLinkManager!=nullptr && pData!=nullptr && pData->mpLink==nullptr) { // don't register twice
+ pData->mpLink = new ImpSdrObjTextLink(this);
+ pLinkManager->InsertFileLink(*pData->mpLink,sfx2::SvBaseLinkObjectType::ClientFile,pData->maFileName,
+ !pData->maFilterName.isEmpty() ?
+ &pData->maFilterName : nullptr);
}
}
@@ -267,10 +267,10 @@ void SdrTextObj::ImpDeregisterLink()
{
ImpSdrObjTextLinkUserData* pData=GetLinkUserData();
sfx2::LinkManager* pLinkManager(getSdrModelFromSdrObject().GetLinkManager());
- if (pLinkManager!=nullptr && pData!=nullptr && pData->pLink!=nullptr) { // don't register twice
+ if (pLinkManager!=nullptr && pData!=nullptr && pData->mpLink!=nullptr) { // don't register twice
// when doing Remove, *pLink is deleted implicitly
- pLinkManager->Remove( pData->pLink.get() );
- pData->pLink=nullptr;
+ pLinkManager->Remove( pData->mpLink.get() );
+ pData->mpLink=nullptr;
}
}
diff --git a/svx/source/svdraw/svdotxtr.cxx b/svx/source/svdraw/svdotxtr.cxx
index e4f7b65fc1b8..f0abb2b9d5a2 100644
--- a/svx/source/svdraw/svdotxtr.cxx
+++ b/svx/source/svdraw/svdotxtr.cxx
@@ -41,7 +41,7 @@ using namespace com::sun::star;
void SdrTextObj::NbcSetSnapRect(const tools::Rectangle& rRect)
{
- if (aGeo.nRotationAngle || aGeo.nShearAngle)
+ if (maGeo.nRotationAngle || maGeo.nShearAngle)
{
// Either the rotation or shear angle exists.
tools::Rectangle aSR0(GetSnapRect());
@@ -83,12 +83,12 @@ void SdrTextObj::NbcSetLogicRect(const tools::Rectangle& rRect)
Degree100 SdrTextObj::GetRotateAngle() const
{
- return aGeo.nRotationAngle;
+ return maGeo.nRotationAngle;
}
Degree100 SdrTextObj::GetShearAngle(bool /*bVertical*/) const
{
- return aGeo.nShearAngle;
+ return maGeo.nShearAngle;
}
void SdrTextObj::NbcMove(const Size& rSiz)
@@ -101,8 +101,8 @@ void SdrTextObj::NbcMove(const Size& rSiz)
void SdrTextObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fraction& yFact)
{
- bool bNotSheared=aGeo.nShearAngle==0_deg100;
- bool bRotate90=bNotSheared && aGeo.nRotationAngle.get() % 9000 ==0;
+ bool bNotSheared=maGeo.nShearAngle==0_deg100;
+ bool bRotate90=bNotSheared && maGeo.nRotationAngle.get() % 9000 ==0;
bool bXMirr=(xFact.GetNumerator()<0) != (xFact.GetDenominator()<0);
bool bYMirr=(yFact.GetNumerator()<0) != (yFact.GetDenominator()<0);
if (bXMirr || bYMirr) {
@@ -119,18 +119,18 @@ void SdrTextObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
}
}
- if (aGeo.nRotationAngle==0_deg100 && aGeo.nShearAngle==0_deg100) {
+ if (maGeo.nRotationAngle==0_deg100 && maGeo.nShearAngle==0_deg100) {
ResizeRect(maRect,rRef,xFact,yFact);
if (bYMirr) {
maRect.Justify();
maRect.Move(maRect.Right()-maRect.Left(),maRect.Bottom()-maRect.Top());
- aGeo.nRotationAngle=18000_deg100;
- aGeo.RecalcSinCos();
+ maGeo.nRotationAngle=18000_deg100;
+ maGeo.RecalcSinCos();
}
}
else
{
- tools::Polygon aPol(Rect2Poly(maRect,aGeo));
+ tools::Polygon aPol(Rect2Poly(maRect,maGeo));
for(sal_uInt16 a(0); a < aPol.GetSize(); a++)
{
@@ -149,24 +149,24 @@ void SdrTextObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
aPol[4] = aPol0[1];
}
- Poly2Rect(aPol, maRect, aGeo);
+ Poly2Rect(aPol, maRect, maGeo);
}
if (bRotate90) {
- bool bRota90=aGeo.nRotationAngle.get() % 9000 ==0;
+ bool bRota90=maGeo.nRotationAngle.get() % 9000 ==0;
if (!bRota90) { // there's seems to be a rounding error occurring: correct it
- Degree100 a=NormAngle36000(aGeo.nRotationAngle);
+ Degree100 a=NormAngle36000(maGeo.nRotationAngle);
if (a<4500_deg100) a=0_deg100;
else if (a<13500_deg100) a=9000_deg100;
else if (a<22500_deg100) a=18000_deg100;
else if (a<31500_deg100) a=27000_deg100;
else a=0_deg100;
- aGeo.nRotationAngle=a;
- aGeo.RecalcSinCos();
+ maGeo.nRotationAngle=a;
+ maGeo.RecalcSinCos();
}
- if (bNotSheared!=(aGeo.nShearAngle==0_deg100)) { // correct a rounding error occurring with Shear
- aGeo.nShearAngle=0_deg100;
- aGeo.RecalcTan();
+ if (bNotSheared!=(maGeo.nShearAngle==0_deg100)) { // correct a rounding error occurring with Shear
+ maGeo.nShearAngle=0_deg100;
+ maGeo.RecalcTan();
}
}
@@ -174,7 +174,7 @@ void SdrTextObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
AdaptTextMinSize();
- if(bTextFrame && !getSdrModelFromSdrObject().IsPasteResize())
+ if(mbTextFrame && !getSdrModelFromSdrObject().IsPasteResize())
{
NbcAdjustTextFrameWidthAndHeight();
}
@@ -194,13 +194,13 @@ void SdrTextObj::NbcRotate(const Point& rRef, Degree100 nAngle, double sn, doubl
maRect.SetTop(aP.Y() );
maRect.SetRight(maRect.Left()+dx );
maRect.SetBottom(maRect.Top()+dy );
- if (aGeo.nRotationAngle==0_deg100) {
- aGeo.nRotationAngle=NormAngle36000(nAngle);
- aGeo.mfSinRotationAngle=sn;
- aGeo.mfCosRotationAngle=cs;
+ if (maGeo.nRotationAngle==0_deg100) {
+ maGeo.nRotationAngle=NormAngle36000(nAngle);
+ maGeo.mfSinRotationAngle=sn;
+ maGeo.mfCosRotationAngle=cs;
} else {
- aGeo.nRotationAngle=NormAngle36000(aGeo.nRotationAngle+nAngle);
- aGeo.RecalcSinCos();
+ maGeo.nRotationAngle=NormAngle36000(maGeo.nRotationAngle+nAngle);
+ maGeo.RecalcSinCos();
}
SetRectsDirty();
NbcRotateGluePoints(rRef,nAngle,sn,cs);
@@ -212,15 +212,15 @@ void SdrTextObj::NbcShear(const Point& rRef, Degree100 /*nAngle*/, double tn, bo
SetGlueReallyAbsolute(true);
// when this is a SdrPathObj, aRect may be uninitialized
- tools::Polygon aPol(Rect2Poly(maRect.IsEmpty() ? GetSnapRect() : maRect, aGeo));
+ tools::Polygon aPol(Rect2Poly(maRect.IsEmpty() ? GetSnapRect() : maRect, maGeo));
sal_uInt16 nPointCount=aPol.GetSize();
for (sal_uInt16 i=0; i<nPointCount; i++) {
ShearPoint(aPol[i],rRef,tn,bVShear);
}
- Poly2Rect(aPol,maRect,aGeo);
+ Poly2Rect(aPol,maRect,maGeo);
ImpJustifyRect(maRect);
- if (bTextFrame) {
+ if (mbTextFrame) {
NbcAdjustTextFrameWidthAndHeight();
}
ImpCheckShear();
@@ -232,14 +232,14 @@ void SdrTextObj::NbcShear(const Point& rRef, Degree100 /*nAngle*/, double tn, bo
void SdrTextObj::NbcMirror(const Point& rRef1, const Point& rRef2)
{
SetGlueReallyAbsolute(true);
- bool bNotSheared=aGeo.nShearAngle==0_deg100;
+ bool bNotSheared=maGeo.nShearAngle==0_deg100;
bool bRotate90 = false;
if (bNotSheared &&
(rRef1.X()==rRef2.X() || rRef1.Y()==rRef2.Y() ||
std::abs(rRef1.X()-rRef2.X())==std::abs(rRef1.Y()-rRef2.Y()))) {
- bRotate90=aGeo.nRotationAngle.get() % 9000 ==0;
+ bRotate90=maGeo.nRotationAngle.get() % 9000 ==0;
}
- tools::Polygon aPol(Rect2Poly(maRect,aGeo));
+ tools::Polygon aPol(Rect2Poly(maRect,maGeo));
sal_uInt16 i;
sal_uInt16 nPointCount=aPol.GetSize();
for (i=0; i<nPointCount; i++) {
@@ -252,28 +252,28 @@ void SdrTextObj::NbcMirror(const Point& rRef1, const Point& rRef2)
aPol[2]=aPol0[3];
aPol[3]=aPol0[2];
aPol[4]=aPol0[1];
- Poly2Rect(aPol,maRect,aGeo);
+ Poly2Rect(aPol,maRect,maGeo);
if (bRotate90) {
- bool bRota90=aGeo.nRotationAngle.get() % 9000 ==0;
+ bool bRota90=maGeo.nRotationAngle.get() % 9000 ==0;
if (bRotate90 && !bRota90) { // there's seems to be a rounding error occurring: correct it
- Degree100 a=NormAngle36000(aGeo.nRotationAngle);
+ Degree100 a=NormAngle36000(maGeo.nRotationAngle);
if (a<4500_deg100) a=0_deg100;
else if (a<13500_deg100) a=9000_deg100;
else if (a<22500_deg100) a=18000_deg100;
else if (a<31500_deg100) a=27000_deg100;
else a=0_deg100;
- aGeo.nRotationAngle=a;
- aGeo.RecalcSinCos();
+ maGeo.nRotationAngle=a;
+ maGeo.RecalcSinCos();
}
}
- if (bNotSheared!=(aGeo.nShearAngle==0_deg100)) { // correct a rounding error occurring with Shear
- aGeo.nShearAngle=0_deg100;
- aGeo.RecalcTan();
+ if (bNotSheared!=(maGeo.nShearAngle==0_deg100)) { // correct a rounding error occurring with Shear
+ maGeo.nShearAngle=0_deg100;
+ maGeo.RecalcTan();
}
ImpJustifyRect(maRect);
- if (bTextFrame) {
+ if (mbTextFrame) {
NbcAdjustTextFrameWidthAndHeight();
}
ImpCheckShear();
diff --git a/svx/source/svdraw/svdouno.cxx b/svx/source/svdraw/svdouno.cxx
index eebe934ddf10..9d16d3a12332 100644
--- a/svx/source/svdraw/svdouno.cxx
+++ b/svx/source/svdraw/svdouno.cxx
@@ -290,20 +290,20 @@ void SdrUnoObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fracti
{
SdrRectObj::NbcResize(rRef,xFact,yFact);
- if (aGeo.nShearAngle==0_deg100 && aGeo.nRotationAngle==0_deg100)
+ if (maGeo.nShearAngle==0_deg100 && maGeo.nRotationAngle==0_deg100)
return;
// small correctors
- if (aGeo.nRotationAngle>=9000_deg100 && aGeo.nRotationAngle<27000_deg100)
+ if (maGeo.nRotationAngle>=9000_deg100 && maGeo.nRotationAngle<27000_deg100)
{
maRect.Move(maRect.Left()-maRect.Right(),maRect.Top()-maRect.Bottom());
}
- aGeo.nRotationAngle = 0_deg100;
- aGeo.nShearAngle = 0_deg100;
- aGeo.mfSinRotationAngle = 0.0;
- aGeo.mfCosRotationAngle = 1.0;
- aGeo.mfTanShearAngle = 0.0;
+ maGeo.nRotationAngle = 0_deg100;
+ maGeo.nShearAngle = 0_deg100;
+ maGeo.mfSinRotationAngle = 0.0;
+ maGeo.mfCosRotationAngle = 1.0;
+ maGeo.mfTanShearAngle = 0.0;
SetRectsDirty();
}
diff --git a/svx/source/svdraw/textchainflow.cxx b/svx/source/svdraw/textchainflow.cxx
index c7c0b173374a..b57f6ceda6c3 100644
--- a/svx/source/svdraw/textchainflow.cxx
+++ b/svx/source/svdraw/textchainflow.cxx
@@ -260,10 +260,10 @@ EditingTextChainFlow::EditingTextChainFlow(SdrTextObj *pLinkTarget) :
void EditingTextChainFlow::CheckForFlowEvents(SdrOutliner *pFlowOutl)
{
// if this is editing outliner no need to set parameters
- if (pFlowOutl == GetLinkTarget()->pEdtOutl)
+ if (pFlowOutl == GetLinkTarget()->mpEdtOutl)
impCheckForFlowEvents(pFlowOutl, nullptr);
else
- impCheckForFlowEvents(pFlowOutl, GetLinkTarget()->pEdtOutl);
+ impCheckForFlowEvents(pFlowOutl, GetLinkTarget()->mpEdtOutl);
// Broadcast events for cursor handling
impBroadcastCursorInfo();
diff --git a/svx/source/table/svdotable.cxx b/svx/source/table/svdotable.cxx
index 05e8dda38e21..ee56034aa58c 100644
--- a/svx/source/table/svdotable.cxx
+++ b/svx/source/table/svdotable.cxx
@@ -878,13 +878,13 @@ SdrTableObj::SdrTableObj(SdrModel& rSdrModel, SdrTableObj const & rSource)
maLogicRect = rSource.maLogicRect;
maRect = rSource.maRect;
- aGeo = rSource.aGeo;
- eTextKind = rSource.eTextKind;
- bTextFrame = rSource.bTextFrame;
- aTextSize = rSource.aTextSize;
- bTextSizeDirty = rSource.bTextSizeDirty;
- bNoShear = rSource.bNoShear;
- bDisableAutoWidthOnDragging = rSource.bDisableAutoWidthOnDragging;
+ maGeo = rSource.maGeo;
+ meTextKind = rSource.meTextKind;
+ mbTextFrame = rSource.mbTextFrame;
+ maTextSize = rSource.maTextSize;
+ mbTextSizeDirty = rSource.mbTextSizeDirty;
+ mbNoShear = rSource.mbNoShear;
+ mbDisableAutoWidthOnDragging = rSource.mbDisableAutoWidthOnDragging;
// use SdrTableObjImpl::operator= now to
// copy model data and other stuff (see there)
@@ -1407,7 +1407,7 @@ sal_Int32 SdrTableObj::CheckTextHit(const Point& rPnt) const
SdrOutliner* SdrTableObj::GetCellTextEditOutliner( const Cell& rCell ) const
{
if( mpImpl.is() && (mpImpl->getCell( mpImpl->maEditPos ).get() == &rCell) )
- return pEdtOutl;
+ return mpEdtOutl;
else
return nullptr;
}
@@ -1435,7 +1435,7 @@ bool SdrTableObj::HasText() const
bool SdrTableObj::IsTextEditActive( const CellPos& rPos )
{
- return pEdtOutl && mpImpl.is() && (rPos == mpImpl->maEditPos);
+ return mpEdtOutl && mpImpl.is() && (rPos == mpImpl->maEditPos);
}
@@ -1524,8 +1524,8 @@ void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, too
// set text at outliner, maybe from edit outliner
OutlinerParaObject* pPara= xCell->GetOutlinerParaObject();
- if (pEdtOutl && !bNoEditText && mpImpl->mxActiveCell == xCell )
- pPara=pEdtOutl->CreateParaObject().release();
+ if (mpEdtOutl && !bNoEditText && mpImpl->mxActiveCell == xCell )
+ pPara=mpEdtOutl->CreateParaObject().release();
if (pPara)
{
@@ -1546,7 +1546,7 @@ void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, too
rOutliner.SetTextObj( nullptr );
}
- if (pEdtOutl && !bNoEditText && pPara && mpImpl->mxActiveCell == xCell )
+ if (mpEdtOutl && !bNoEditText && pPara && mpImpl->mxActiveCell == xCell )
delete pPara;
rOutliner.SetUpdateMode(true);
@@ -1808,10 +1808,10 @@ void SdrTableObj::RecalcSnapRect()
bool SdrTableObj::BegTextEdit(SdrOutliner& rOutl)
{
- if( pEdtOutl != nullptr )
+ if( mpEdtOutl != nullptr )
return false;
- pEdtOutl=&rOutl;
+ mpEdtOutl=&rOutl;
mbInEditMode = true;
@@ -1877,7 +1877,7 @@ void SdrTableObj::EndTextEdit(SdrOutliner& rOutl)
SetOutlinerParaObject(std::move(pNewText));
}
- pEdtOutl = nullptr;
+ mpEdtOutl = nullptr;
rOutl.Clear();
EEControlBits nStat = rOutl.GetControlWord();
nStat &= ~EEControlBits::AUTOPAGESIZE;
@@ -2060,7 +2060,7 @@ void SdrTableObj::SetSkipChangeLayout(bool bSkipChangeLayout)
bool SdrTableObj::IsReallyEdited() const
{
- return pEdtOutl && pEdtOutl->IsModified();
+ return mpEdtOutl && mpEdtOutl->IsModified();
}
bool SdrTableObj::IsFontwork() const
diff --git a/svx/source/unodraw/unoshap2.cxx b/svx/source/unodraw/unoshap2.cxx
index 5fa0596ef98c..22d719c204d1 100644
--- a/svx/source/unodraw/unoshap2.cxx
+++ b/svx/source/unodraw/unoshap2.cxx
@@ -1613,7 +1613,7 @@ awt::Point SAL_CALL SvxCustomShape::getPosition()
if ( bMirroredX || bMirroredY )
{ // we have to retrieve the unmirrored rect
- GeoStat aNewGeo( aCustomShapeGeoData.aGeo );
+ GeoStat aNewGeo(aCustomShapeGeoData.maGeo);
if ( bMirroredX )
{
tools::Polygon aPol( Rect2Poly( aRect, aNewGeo ) );
diff --git a/svx/source/svdraw/svdoashp.cxx b/svx/source/svdraw/svdoashp.cxx
index bd0a4b1bc834..259855c09935 100644
--- a/svx/source/svdraw/svdoashp.cxx
+++ b/svx/source/svdraw/svdoashp.cxx
@@ -792,7 +792,7 @@ SdrObjCustomShape::SdrObjCustomShape(SdrModel& rSdrModel)
, mpLastShadowGeometry(nullptr)
{
m_bClosedObj = true; // custom shapes may be filled
- bTextFrame = true;
+ mbTextFrame = true;
}
SdrObjCustomShape::SdrObjCustomShape(SdrModel& rSdrModel, SdrObjCustomShape const & rSource)
@@ -802,7 +802,7 @@ SdrObjCustomShape::SdrObjCustomShape(SdrModel& rSdrModel, SdrObjCustomShape cons
, mpLastShadowGeometry(nullptr)
{
m_bClosedObj = true; // custom shapes may be filled
- bTextFrame = true;
+ mbTextFrame = true;
fObjectRotation = rSource.fObjectRotation;
mbAdjustingTextFrameWidthAndHeight = rSource.mbAdjustingTextFrameWidthAndHeight;
@@ -1545,7 +1545,7 @@ void SdrObjCustomShape::NbcResize( const Point& rRef, const Fraction& rxFact, co
}
// updating fObjectRotation
- Degree100 nTextObjRotation = aGeo.nRotationAngle;
+ Degree100 nTextObjRotation = maGeo.nRotationAngle;
double fAngle = toDegrees(nTextObjRotation);
if (IsMirroredX())
{
@@ -1579,12 +1579,12 @@ void SdrObjCustomShape::NbcRotate( const Point& rRef, Degree100 nAngle, double s
fObjectRotation = 360 + fObjectRotation;
// the rotation angle for ashapes is stored in fObjectRotation, this rotation
- // has to be applied to the text object (which is internally using aGeo.nAngle).
- SdrTextObj::NbcRotate( maRect.TopLeft(), -aGeo.nRotationAngle, // retrieving the unrotated text object
- -aGeo.mfSinRotationAngle,
- aGeo.mfCosRotationAngle );
- aGeo.nRotationAngle = 0_deg100; // resetting aGeo data
- aGeo.RecalcSinCos();
+ // has to be applied to the text object (which is internally using maGeo.nAngle).
+ SdrTextObj::NbcRotate( maRect.TopLeft(), -maGeo.nRotationAngle, // retrieving the unrotated text object
+ -maGeo.mfSinRotationAngle,
+ maGeo.mfCosRotationAngle );
+ maGeo.nRotationAngle = 0_deg100; // resetting aGeo data
+ maGeo.RecalcSinCos();
tools::Long nW = static_cast<tools::Long>( fObjectRotation * 100 ); // applying our object rotation
if ( bMirroredX )
@@ -1641,7 +1641,7 @@ void SdrObjCustomShape::NbcMirror( const Point& rRef1, const Point& rRef2 )
SdrTextObj::NbcMirror( rRef1, rRef2 );
// update fObjectRotation
- Degree100 nTextObjRotation = aGeo.nRotationAngle;
+ Degree100 nTextObjRotation = maGeo.nRotationAngle;
double fAngle = toDegrees(nTextObjRotation);
bool bSingleFlip = (IsMirroredX()!= IsMirroredY());
@@ -1669,7 +1669,7 @@ void SdrObjCustomShape::NbcShear( const Point& rRef, Degree100 nAngle, double tn
SdrTextObj::NbcShear(rRef,nAngle,tn,bVShear);
// updating fObjectRotation
- Degree100 nTextObjRotation = aGeo.nRotationAngle;
+ Degree100 nTextObjRotation = maGeo.nRotationAngle;
double fAngle = toDegrees(nTextObjRotation);
if (IsMirroredX())
{
@@ -1711,8 +1711,8 @@ SdrGluePoint SdrObjCustomShape::GetVertexGluePoint(sal_uInt16 nPosNum) const
case 2: aPt=maRect.BottomCenter(); aPt.AdjustY(nWdt ); break;
case 3: aPt=maRect.LeftCenter(); aPt.AdjustX( -nWdt ); break;
}
- if (aGeo.nShearAngle!=0_deg100) ShearPoint(aPt,maRect.TopLeft(),aGeo.mfTanShearAngle);
- if (aGeo.nRotationAngle!=0_deg100) RotatePoint(aPt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nShearAngle != 0_deg100) ShearPoint(aPt, maRect.TopLeft(), maGeo.mfTanShearAngle);
+ if (maGeo.nRotationAngle != 0_deg100) RotatePoint(aPt, maRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aPt-=GetSnapRect().Center();
SdrGluePoint aGP(aPt);
aGP.SetPercent(false);
@@ -1756,10 +1756,10 @@ void SdrObjCustomShape::ImpCheckCustomGluePointsAreAdded()
bool bMirroredX = IsMirroredX();
bool bMirroredY = IsMirroredY();
- Degree100 nShearAngle = aGeo.nShearAngle;
- double fTan = aGeo.mfTanShearAngle;
+ Degree100 nShearAngle = maGeo.nShearAngle;
+ double fTan = maGeo.mfTanShearAngle;
- if ( aGeo.nRotationAngle || nShearAngle || bMirroredX || bMirroredY )
+ if (maGeo.nRotationAngle || nShearAngle || bMirroredX || bMirroredY)
{
tools::Polygon aPoly( maRect );
if( nShearAngle )
@@ -1768,8 +1768,8 @@ void SdrObjCustomShape::ImpCheckCustomGluePointsAreAdded()
for (sal_uInt16 i=0; i<nPointCount; i++)
ShearPoint(aPoly[i],maRect.Center(), fTan );
}
- if ( aGeo.nRotationAngle )
- aPoly.Rotate( maRect.Center(), toDegree10(aGeo.nRotationAngle) );
+ if (maGeo.nRotationAngle)
+ aPoly.Rotate( maRect.Center(), toDegree10(maGeo.nRotationAngle) );
tools::Rectangle aBoundRect( aPoly.GetBoundRect() );
sal_Int32 nXDiff = aBoundRect.Left() - maRect.Left();
@@ -1930,11 +1930,11 @@ void SdrObjCustomShape::DragResizeCustomShape( const tools::Rectangle& rNewRect
GeoStat aGeoStat( GetGeoStat() );
if ( aNewRect.TopLeft()!= maRect.TopLeft() &&
- ( aGeo.nRotationAngle || aGeo.nShearAngle ) )
+ ( maGeo.nRotationAngle || maGeo.nShearAngle ) )
{
Point aNewPos( aNewRect.TopLeft() );
- if ( aGeo.nShearAngle ) ShearPoint( aNewPos, aOld.TopLeft(), aGeoStat.mfTanShearAngle );
- if ( aGeo.nRotationAngle ) RotatePoint(aNewPos, aOld.TopLeft(), aGeoStat.mfSinRotationAngle, aGeoStat.mfCosRotationAngle );
+ if ( maGeo.nShearAngle ) ShearPoint( aNewPos, aOld.TopLeft(), aGeoStat.mfTanShearAngle );
+ if ( maGeo.nRotationAngle ) RotatePoint(aNewPos, aOld.TopLeft(), aGeoStat.mfSinRotationAngle, aGeoStat.mfCosRotationAngle );
aNewRect.SetPos( aNewPos );
}
if ( aNewRect == maRect )
@@ -2298,17 +2298,17 @@ bool SdrObjCustomShape::AdjustTextFrameWidthAndHeight(tools::Rectangle& rR, bool
if (HasText())
{
- if(pEdtOutl)
+ if(mpEdtOutl)
{
- pEdtOutl->SetMaxAutoPaperSize( aSiz );
+ mpEdtOutl->SetMaxAutoPaperSize( aSiz );
if (bWdtGrow)
{
- Size aSiz2(pEdtOutl->CalcTextSize());
+ Size aSiz2(mpEdtOutl->CalcTextSize());
nWdt=aSiz2.Width()+1; // a little more tolerance
if (bHgtGrow) nHgt=aSiz2.Height()+1; // a little more tolerance
} else
{
- nHgt=pEdtOutl->GetTextHeight()+1; // a little more tolerance
+ nHgt=mpEdtOutl->GetTextHeight()+1; // a little more tolerance
}
}
else
@@ -2398,12 +2398,12 @@ bool SdrObjCustomShape::AdjustTextFrameWidthAndHeight(tools::Rectangle& rR, bool
rR.SetBottom(rR.Top()+nHgt );
}
}
- if ( aGeo.nRotationAngle )
+ if ( maGeo.nRotationAngle )
{
Point aD1(rR.TopLeft());
aD1-=aR0.TopLeft();
Point aD2(aD1);
- RotatePoint(aD2,Point(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aD2,Point(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aD2-=aD1;
rR.Move(aD2.X(),aD2.Y());
}
@@ -2517,12 +2517,12 @@ void SdrObjCustomShape::TakeTextEditArea(Size* pPaperMin, Size* pPaperMax, tools
{
tools::Rectangle aViewInit;
TakeTextAnchorRect( aViewInit );
- if ( aGeo.nRotationAngle )
+ if (maGeo.nRotationAngle)
{
Point aCenter(aViewInit.Center());
aCenter-=aViewInit.TopLeft();
Point aCenter0(aCenter);
- RotatePoint(aCenter,Point(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aCenter, Point(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
aCenter-=aCenter0;
aViewInit.Move(aCenter.X(),aCenter.Y());
}
@@ -2619,10 +2619,10 @@ void SdrObjCustomShape::TakeTextAnchorRect( tools::Rectangle& rAnchorRect ) cons
rAnchorRect.SetRight( rAnchorRect.Left() + 1 ); // minimal width is 2
if ( rAnchorRect.GetHeight() < 2 )
rAnchorRect.SetBottom( rAnchorRect.Top() + 1 ); // minimal height is 2
- if ( aGeo.nRotationAngle )
+ if (maGeo.nRotationAngle)
{
Point aP( rAnchorRect.TopLeft() );
- RotatePoint( aP, aRotateRef, aGeo.mfSinRotationAngle, aGeo.mfCosRotationAngle );
+ RotatePoint(aP, aRotateRef, maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
rAnchorRect.SetPos( aP );
}
}
@@ -2668,8 +2668,8 @@ void SdrObjCustomShape::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle&
// put text into the Outliner - if necessary the use the text from the EditOutliner
OutlinerParaObject* pPara= GetOutlinerParaObject();
- if (pEdtOutl && !bNoEditText)
- pPara=pEdtOutl->CreateParaObject().release();
+ if (mpEdtOutl && !bNoEditText)
+ pPara=mpEdtOutl->CreateParaObject().release();
if (pPara)
{
@@ -2690,7 +2690,7 @@ void SdrObjCustomShape::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle&
{
rOutliner.SetTextObj( nullptr );
}
- if (pEdtOutl && !bNoEditText && pPara)
+ if (mpEdtOutl && !bNoEditText && pPara)
delete pPara;
rOutliner.SetUpdateMode(true);
@@ -2753,8 +2753,8 @@ void SdrObjCustomShape::TakeTextRect( SdrOutliner& rOutliner, tools::Rectangle&
if (eVAdj==SDRTEXTVERTADJUST_BOTTOM)
aTextPos.AdjustY(nFreeHgt );
}
- if (aGeo.nRotationAngle!=0_deg100)
- RotatePoint(aTextPos,aAnkRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ if (maGeo.nRotationAngle != 0_deg100)
+ RotatePoint(aTextPos,aAnkRect.TopLeft(), maGeo.mfSinRotationAngle, maGeo.mfCosRotationAngle);
if (pAnchorRect)
*pAnchorRect=aAnkRect;
@@ -2994,10 +2994,10 @@ void SdrObjCustomShape::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix,
// reset object shear and rotations
fObjectRotation = 0.0;
- aGeo.nRotationAngle = 0_deg100;
- aGeo.RecalcSinCos();
- aGeo.nShearAngle = 0_deg100;
- aGeo.RecalcTan();
+ maGeo.nRotationAngle = 0_deg100;
+ maGeo.RecalcSinCos();
+ maGeo.nShearAngle = 0_deg100;
+ maGeo.RecalcTan();
// if anchor is used, make position relative to it
if(getSdrModelFromSdrObject().IsWriter())
@@ -3083,7 +3083,7 @@ bool SdrObjCustomShape::TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegf
{
// get turn and shear
double fRotate = basegfx::deg2rad(fObjectRotation);
- double fShearX = toRadians(aGeo.nShearAngle);
+ double fShearX = toRadians(maGeo.nShearAngle);
// get aRect, this is the unrotated snaprect
tools::Rectangle aRectangle(maRect);
@@ -3093,7 +3093,7 @@ bool SdrObjCustomShape::TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegf
if ( bMirroredX || bMirroredY )
{ // we have to retrieve the unmirrored rect
- GeoStat aNewGeo( aGeo );
+ GeoStat aNewGeo(maGeo);
if ( bMirroredX )
{
diff --git a/svx/source/svdraw/svdopath.cxx b/svx/source/svdraw/svdopath.cxx
index a9aaefae3239..0338e80b7f6c 100644
--- a/svx/source/svdraw/svdopath.cxx
+++ b/svx/source/svdraw/svdopath.cxx
@@ -1679,10 +1679,10 @@ void SdrPathObj::ImpForceLineAngle()
const basegfx::B2DPoint aB2DDelt(aB2DPoint1 - aB2DPoint0);
const Point aDelt(FRound(aB2DDelt.getX()), FRound(aB2DDelt.getY()));
- aGeo.nRotationAngle=GetAngle(aDelt);
- aGeo.nShearAngle=0_deg100;
- aGeo.RecalcSinCos();
- aGeo.RecalcTan();
+ maGeo.nRotationAngle=GetAngle(aDelt);
+ maGeo.nShearAngle=0_deg100;
+ maGeo.RecalcSinCos();
+ maGeo.RecalcTan();
// for SdrTextObj, keep aRect up to date
maRect = tools::Rectangle::Justify(aPoint0, aPoint1);
@@ -2271,7 +2271,7 @@ void SdrPathObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
if(basegfx::fTools::equal(fResizeX, 1.0) && basegfx::fTools::equal(fResizeY, 1.0))
{
// tdf#106792 avoid numerical unprecisions: If both scale factors are 1.0, do not
// manipulate at all - that may change aGeo rapidly (and wrongly) in
// SdrTextObj::NbcResize. Combined with the UNO API trying to not 'apply'
// a rotation but to manipulate the existing one, this is fatal. So just
// avoid this error as long as we have to deal with imprecise geometry
@@ -2341,17 +2341,17 @@ void SdrPathObj::NbcMirror(const Point& rRefPnt1, const Point& rRefPnt2)
void SdrPathObj::TakeUnrotatedSnapRect(tools::Rectangle& rRect) const
{
- if(!aGeo.nRotationAngle)
+ if(!maGeo.nRotationAngle)
{
rRect = GetSnapRect();
}
else
{
XPolyPolygon aXPP(GetPathPoly());
- RotateXPoly(aXPP,Point(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotateXPoly(aXPP,Point(),-maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
rRect=aXPP.GetBoundRect();
Point aTmp(rRect.TopLeft());
- RotatePoint(aTmp,Point(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
+ RotatePoint(aTmp,Point(),maGeo.mfSinRotationAngle,maGeo.mfCosRotationAngle);
aTmp-=rRect.TopLeft();
rRect.Move(aTmp.X(),aTmp.Y());
}
@@ -2803,17 +2803,17 @@ bool SdrPathObj::TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegfx::B2DP
}
else
{
- if(aGeo.nShearAngle || aGeo.nRotationAngle)
+ if(maGeo.nShearAngle || maGeo.nRotationAngle)
{
// get rotate and shear in drawingLayer notation
- fRotate = aGeo.nRotationAngle.get() * F_PI18000;
- fShearX = aGeo.nShearAngle.get() * F_PI18000;
+ fRotate = maGeo.nRotationAngle.get() * F_PI18000;
+ fShearX = maGeo.nShearAngle.get() * F_PI18000;
// build mathematically correct (negative shear and rotate) object transform
// containing shear and rotate to extract unsheared, unrotated polygon
basegfx::B2DHomMatrix aObjectMatrix;
- aObjectMatrix.shearX(-aGeo.mfTanShearAngle);
- aObjectMatrix.rotate((36000 - aGeo.nRotationAngle.get()) * F_PI18000);
+ aObjectMatrix.shearX(-maGeo.mfTanShearAngle);
+ aObjectMatrix.rotate((36000 - maGeo.nRotationAngle.get()) * F_PI18000);
// create inverse from it and back-transform polygon
basegfx::B2DHomMatrix aInvObjectMatrix(aObjectMatrix);
@@ -2901,10 +2901,10 @@ void SdrPathObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
basegfx::B2DPolyPolygon aNewPolyPolygon(rPolyPolygon);
// reset object shear and rotations
- aGeo.nRotationAngle = 0_deg100;
- aGeo.RecalcSinCos();
- aGeo.nShearAngle = 0_deg100;
- aGeo.RecalcTan();
+ maGeo.nRotationAngle = 0_deg100;
+ maGeo.RecalcSinCos();
+ maGeo.nShearAngle = 0_deg100;
+ maGeo.RecalcTan();
if( getSdrModelFromSdrObject().IsWriter() )
{
@@ -2915,7 +2915,7 @@ void SdrPathObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
}
}
// create transformation for polygon, set values at aGeo direct
basegfx::B2DHomMatrix aTransform;
// #i75086#
@@ -2949,8 +2949,8 @@ void SdrPathObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
if(!basegfx::fTools::equalZero(fShearX))
{
aTransform.shearX(tan(-atan(fShearX)));
- aGeo.nShearAngle = Degree100(FRound(atan(fShearX) / F_PI18000));
- aGeo.RecalcTan();
+ maGeo.nShearAngle = Degree100(FRound(atan(fShearX) / F_PI18000));
+ maGeo.RecalcTan();
}
if(!basegfx::fTools::equalZero(fRotate))
@@ -2963,8 +2963,8 @@ void SdrPathObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
// #i78696#
// fRotate is mathematically correct, but aGeoStat.nRotationAngle is
// mirrored -> mirror value here
- aGeo.nRotationAngle = NormAngle36000(Degree100(FRound(-fRotate / F_PI18000)));
- aGeo.RecalcSinCos();
+ maGeo.nRotationAngle = NormAngle36000(Degree100(FRound(-fRotate / F_PI18000)));
+ maGeo.RecalcSinCos();
}
if(!aTranslate.equalZero())
@@ -2271,7 +2271,7 @@ void SdrPathObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
{
// tdf#106792 avoid numerical unprecisions: If both scale factors are 1.0, do not
- // manipulate at all - that may change aGeo rapidly (and wrongly) in
+ // manipulate at all - that may change maGeo rapidly (and wrongly) in
// SdrTextObj::NbcResize. Combined with the UNO API trying to not 'apply'
// a rotation but to manipulate the existing one, this is fatal. So just
@@ -2915,7 +2915,7 @@ void SdrPathObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, const b
}
}
- // create transformation for polygon, set values at aGeo direct
+ // create transformation for polygon, set values at maGeo direct
basegfx::B2DHomMatrix aTransform;
// #i75086#